#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InXM v7'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = 4
ACQFFT = "".join(
    chr(c)
    for c in [70, 97, 110, 83, 101, 116, 65, 79, 84, 84, 101, 109, 112, 65, 100, 99]
)
AFIKJP = "".join(chr(c) for c in [65, 109, 80, 109])
AHEOCT = "".join(chr(c) for c in [79, 117, 116, 49, 65, 67, 117, 114])
AIIDNI = "".join(chr(c) for c in [78, 111, 65, 99, 116, 105, 111, 110])
AKQXPI = "".join(chr(c) for c in [83, 112, 76, 105, 102, 116])
AMJMAO = 44
AOAWBS = 15
AONPYY = "".join(
    chr(c) for c in [81, 117, 105, 101, 116, 84, 105, 109, 101, 79, 117, 116]
)
ASSAKQ = "".join(chr(c) for c in [70, 98, 76, 105])
AWBSIR = 13
BDJQRJ = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 51]
)
BFEGZU = "".join(chr(c) for c in [76, 73])
BIAMJM = 57
BJEUTO = "".join(chr(c) for c in [65, 118, 97, 105, 108, 97, 98, 108, 101])
BLKXSJ = 46
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49, 65])
BQFYLJ = "".join(chr(c) for c in [78, 111])
BQNRXC = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 53, 78, 98, 87, 101, 101, 107]
)
BQSNQL = 86
BSIRYX = "".join(chr(c) for c in [70])
BSKSOK = 109
BSSUHB = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        70,
        111,
        114,
        99,
        101,
        79,
        102,
        102,
        73,
        110,
        104,
        105,
        98,
        105,
        116,
        68,
        101,
        108,
        97,
        121,
    ]
)
BVWVUB = "".join(
    chr(c)
    for c in [86, 83, 80, 67, 104, 101, 99, 107, 102, 108, 111, 83, 112, 101, 101, 100]
)
BWJYKL = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
BXTIAC = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        70,
        111,
        114,
        99,
        101,
        79,
        70,
        70,
        79,
        112,
        116,
        105,
        111,
        110,
    ]
)
BXYBQS = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
BYGDSB = 8
CBFEGZ = 103
CCPQIP = "".join(chr(c) for c in [67, 112, 79, 116, 79, 112, 116, 105, 111, 110])
CHWDAF = 81
CPQIPO = 23
CQBMJV = 0
CQFFTT = 17
CRTFMN = 38
CTHBSK = "".join(chr(c) for c in [79, 117, 116, 50, 65, 67, 117, 114])
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = "".join(
    chr(c) for c in [70, 105, 98, 101, 114, 84, 105, 109, 101, 79, 117, 116]
)
CXQIEF = 94
DAFIKJ = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
DJQRJJ = 11
DNQGVU = 68
DQLAII = "".join(chr(c) for c in [80, 97, 117, 115, 101])
DSBDJQ = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 50]
)
DUBSSU = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        67,
        108,
        114,
        70,
        111,
        114,
        99,
        101,
        79,
        102,
        102,
        84,
        101,
        109,
        112,
        65,
        100,
        99,
    ]
)
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFJTAC = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
EFXQGL = 96
EGZUQE = "".join(chr(c) for c in [79, 117, 116, 73, 79, 50])
EJNIBX = "".join(chr(c) for c in [76, 105, 110, 101, 86, 111, 108, 116, 97, 103, 101])
EKVKZI = 91
ELHBQN = 77
EOCTHB = "".join(chr(c) for c in [79, 117, 116, 49, 66, 67, 117, 114])
EUTOPH = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
EXLSXU = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
FCRTFM = "".join(chr(c) for c in [79, 110, 122, 101, 110, 68, 117, 114])
FEFJTA = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
FFTTID = 18
FIKJPU = "".join(chr(c) for c in [50, 52, 104])
FJBIAM = 56
FMNHTB = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTTIDU = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        99,
        116,
        105,
        118,
        101,
        68,
        101,
        108,
        97,
        121,
        65,
        102,
        116,
        101,
        114,
        80,
        117,
        109,
        112,
        82,
        117,
        110,
    ]
)
FWRKIN = 62
FXQGLR = "".join(chr(c) for c in [79, 117, 116, 51, 65])
GDSBDJ = 9
GLRAHE = 102
GQPLSP = 54
GSELHB = 76
GTYIYW = "".join(chr(c) for c in [75, 54, 48, 48, 70, 111, 114, 77, 97, 121])
GVUNXN = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 52])
GYOUSP = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
GZUQEX = 104
HBQNRX = 78
HBSKSO = "".join(chr(c) for c in [79, 117, 116, 50, 66, 67, 117, 114])
HBVWVU = "".join(chr(c) for c in [80, 117, 109, 112, 51, 65, 115, 86, 83, 80])
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = 106
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HTBJEU = 65
HUOJRJ = "".join(chr(c) for c in [79, 117, 116, 54, 65])
HWDAFI = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 56, 78, 98, 87, 101, 101, 107]
)
HXEKVK = 90
IACQFF = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        115,
        67,
        111,
        111,
        108,
        105,
        110,
        103,
        68,
        101,
        118,
        105,
        99,
        101,
    ]
)
IAMJMA = "".join(chr(c) for c in [83, 97, 110, 105, 76, 101, 118, 101, 108])
IBXTIA = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        99,
        116,
        105,
        118,
        101,
        79,
        110,
        80,
        117,
        109,
        112,
        82,
        117,
        110,
    ]
)
ICXQIE = "".join(chr(c) for c in [79, 117, 116, 49, 66])
IDNIBX = "".join(chr(c) for c in [75, 101, 101, 112, 79, 102, 102])
IDUBSS = 20
IEFXQG = "".join(chr(c) for c in [79, 117, 116, 50, 66])
IFJBIA = "".join(chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 66, 121])
IGYOUS = 48
IIDNIB = "".join(
    chr(c) for c in [70, 111, 114, 99, 101, 77, 97, 120, 80, 111, 119, 101, 114]
)
IJUGSE = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 49, 78, 98, 87, 101, 101, 107]
)
IKFWRK = 5
ILXWAJ = "".join(
    chr(c)
    for c in [85, 68, 65, 99, 116, 105, 111, 110, 79, 110, 81, 117, 105, 101, 116]
)
IPIVLA = "".join(chr(c) for c in [79, 51])
IPOUYN = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
IRYXBQ = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
IUSOOQ = "".join(chr(c) for c in [79, 117, 116, 52, 65, 67, 117, 114])
IVLASS = "".join(chr(c) for c in [])
IYWSKW = "".join(chr(c) for c in [67, 108, 101, 97, 110, 70, 105, 108, 116, 101, 114])
JBIAMJ = "".join(
    chr(c) for c in [79, 51, 70, 105, 108, 116, 101, 114, 68, 101, 108, 97, 121]
)
JHIUSO = 116
JIGYOU = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
JJJVYF = 28
JJVYFC = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
JMAOAW = 45
JMCBFE = 115
JNIBXY = "".join(chr(c) for c in [50, 52, 48, 86, 97, 99])
JQRJJJ = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
JRJHIU = 101
JTACCP = "".join(
    chr(c) for c in [70, 105, 108, 116, 79, 84, 79, 112, 116, 105, 111, 110]
)
JUGSEL = 75
JUIKFW = 14
JUTYEK = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
JVDQLA = "".join(
    chr(c)
    for c in [81, 117, 105, 101, 116, 65, 99, 116, 105, 111, 110, 79, 110, 85, 68]
)
JVHFTH = "".join(chr(c) for c in [78, 65])
JVYFCR = 30
JWMNZM = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 67, 80, 79, 84, 68, 101, 97, 100, 98, 97, 110, 100]
)
JYKLGQ = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
JYMOUN = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
KCWAON = 2
KFWRKI = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        66,
        101,
        108,
        111,
        119,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
    ]
)
KINEJN = "".join(chr(c) for c in [53, 48, 72, 90])
KJPUNR = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 69, 110, 97, 98, 108, 101]
)
KMLOIJ = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 55])
KPHUOJ = "".join(chr(c) for c in [79, 117, 116, 53, 65])
KQXPIC = "".join(chr(c) for c in [83, 65, 78, 73])
KSOKPH = 110
KVKZIL = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 53])
KWIVDN = "".join(chr(c) for c in [67, 108, 101, 97, 110, 67, 111, 118, 101, 114])
KXSJWM = 47
KZILXW = "".join(
    chr(c) for c in [67, 69, 95, 50, 120, 50, 48, 65, 108, 108, 111, 119, 101, 100]
)
LAIIDN = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        101,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
        79,
        110,
        72,
        101,
        97,
        116,
        101,
        114,
    ]
)
LASSAK = "".join(chr(c) for c in [70, 98, 77, 116, 114])
LGQPLS = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
LHBQNR = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 52, 78, 98, 87, 101, 101, 107]
)
LIUXFE = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
LJUIKF = "".join(
    chr(c) for c in [69, 120, 116, 80, 114, 111, 98, 101, 69, 110, 97, 98, 108, 101]
)
LKXSJW = "".join(
    chr(c) for c in [70, 105, 108, 116, 79, 84, 68, 101, 97, 100, 98, 97, 110, 100]
)
LNMHXE = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 50])
LOIJUG = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 56])
LRAHEO = "".join(chr(c) for c in [72, 84, 82])
LSPFTS = 59
LSXUJU = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
LXWAJV = "".join(chr(c) for c in [73, 103, 110, 111, 114, 101, 85, 68])
MAOAWB = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
MCBFEG = "".join(chr(c) for c in [79, 117, 116, 76, 105])
MHXEKV = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 51])
MJIGYO = 52
MJMAOA = "".join(chr(c) for c in [83, 97, 110, 105, 79, 110, 84, 105, 109, 101])
MJVHFT = 93
MLOIJU = 73
MNHTBJ = 63
MNZMJI = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
MOUNBL = "".join(chr(c) for c in [72, 105])
NBLKXS = "".join(
    chr(c) for c in [70, 105, 108, 116, 79, 84, 65, 99, 116, 84, 101, 109, 112]
)
NEJNIB = 1
NHTBJE = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 111, 112])
NIBXTI = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        99,
        116,
        105,
        118,
        101,
        79,
        110,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        84,
    ]
)
NIBXYB = "".join(chr(c) for c in [50, 51, 48, 86, 65, 67])
NKMLOI = 72
NMHXEK = 89
NPYYLI = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
NQGVUN = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 51])
NQLNMH = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 49])
NRSJMC = "".join(chr(c) for c in [79, 117, 116, 55, 65, 67, 117, 114])
NRXCHW = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 54, 78, 98, 87, 101, 101, 107]
)
NXNKML = 71
NZMJIG = 51
OAWBSI = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
OCTHBS = 107
OIJUGS = 74
OJRJHI = "".join(chr(c) for c in [79, 117, 116, 55, 65])
OKPHUO = 98
ONPYYL = 61
OOQNRS = 112
OPHUGT = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
OQNRSJ = "".join(chr(c) for c in [79, 117, 116, 54, 65, 67, 117, 114])
OUSPBW = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
OUYNQJ = "".join(
    chr(c) for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121]
)
PFTSIF = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
PHUGTY = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
PHUOJR = 99
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
PQIPOU = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
PYYLIU = 26
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = 105
QFFTTI = "".join(
    chr(c)
    for c in [70, 97, 110, 67, 108, 114, 65, 79, 84, 84, 101, 109, 112, 65, 100, 99]
)
QFYLJU = "".join(
    chr(c) for c in [70, 117, 108, 108, 80, 111, 119, 101, 114, 79, 110, 108, 121]
)
QGLRAH = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
QGVUNX = 69
QIEFXQ = 95
QIPOUY = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
QJYMOU = 6
QLNMHX = 88
QNRSJM = 113
QNRXCH = 79
QRJJJV = 27
QSNQLN = "".join(chr(c) for c in [66, 114, 83, 101, 116, 73, 110, 100, 101, 120])
QXPICX = "".join(chr(c) for c in [79, 78, 90, 69, 78])
RJHIUS = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
RJJJVY = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
RKINEJ = "".join(chr(c) for c in [54, 48, 72, 90])
RSJMCB = 114
RTFMNH = "".join(chr(c) for c in [79, 110, 122, 101, 110, 70, 114, 101, 113])
RXCHWD = 80
RYXBQF = 12
SAKQXP = "".join(chr(c) for c in [84, 118, 76, 105, 102, 116])
SBDJQR = 10
SELHBQ = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 51, 78, 98, 87, 101, 101, 107]
)
SIFJBI = 58
SJMCBF = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
SJWMNZ = 49
SKSOKP = "".join(chr(c) for c in [79, 117, 116, 51, 65, 67, 117, 114])
SKWIVD = "".join(chr(c) for c in [67, 104, 97, 110, 103, 101, 87, 97, 116, 101, 114])
SNQLNM = 87
SOKPHU = "".join(chr(c) for c in [79, 117, 116, 52, 65])
SOOQNR = "".join(chr(c) for c in [79, 117, 116, 53, 65, 67, 117, 114])
SPBWJY = "".join(chr(c) for c in [80, 49])
SPFTSI = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
SSAKQX = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
SSUHBV = 22
SUHBVW = "".join(chr(c) for c in [80, 117, 109, 112, 49, 65, 115, 86, 83, 80])
SXUJUT = 4
TACCPQ = 25
TBJEUT = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
TFMNHT = 40
THBSKS = 108
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = "".join(chr(c) for c in [70, 97, 110, 80, 117, 109, 112])
TIDUBS = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        83,
        101,
        116,
        70,
        111,
        114,
        99,
        101,
        79,
        102,
        102,
        84,
        101,
        109,
        112,
        65,
        100,
        99,
    ]
)
TOPHUG = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
TSIFJB = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
TTIDUB = 19
TYEKCW = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
TYIYWS = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 49])
UBSSUH = 21
UBYGDS = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 48]
)
UGSELH = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 50, 78, 98, 87, 101, 101, 107]
)
UGTYIY = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        99,
        107,
        79,
        110,
        79,
        102,
        102,
        75,
        101,
        121,
        69,
        110,
        97,
        98,
        108,
        101,
    ]
)
UHBVWV = 5
UIKFWR = "".join(
    chr(c)
    for c in [
        79,
        118,
        101,
        114,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
        69,
        110,
        97,
        98,
        108,
        101,
    ]
)
UJUTYE = 2
UNBLKX = 0
UNXNKM = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 53])
UOJRJH = 100
UQEXLS = "".join(chr(c) for c in [79, 117, 116, 73, 79, 52])
USOOQN = 111
USPBWJ = 117
UTOPHU = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
UTYEKC = 1
UXFEFJ = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
UYNQJY = "".join(chr(c) for c in [65, 110, 121, 85, 68])
VDNQGV = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 50])
VDQLAI = "".join(chr(c) for c in [67, 97, 110, 99, 101, 108])
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = 92
VLASSA = "".join(chr(c) for c in [70, 65, 78])
VUBYGD = 7
VUNXNK = 70
VWVUBY = 6
VYFCRT = "".join(chr(c) for c in [79, 110, 122, 101, 110, 83, 116, 97, 114, 116])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAJVDQ = "".join(
    chr(c) for c in [67, 97, 110, 99, 101, 108, 79, 116, 104, 101, 114, 85, 68]
)
WAONPY = 3
WBSIRY = "".join(chr(c) for c in [67])
WDAFIK = 82
WIVDNQ = "".join(
    chr(c) for c in [82, 101, 112, 108, 97, 99, 101, 70, 105, 108, 116, 101, 114]
)
WJYKLG = 55
WMNZMJ = 50
WRKINE = "".join(
    chr(c) for c in [76, 105, 110, 101, 70, 114, 101, 113, 117, 101, 110, 99, 121]
)
WSKWIV = "".join(chr(c) for c in [67, 104, 101, 99, 107, 71, 70, 67, 73])
WVUBYG = "".join(
    chr(c) for c in [86, 83, 80, 70, 105, 108, 116, 101, 114, 83, 112, 101, 101, 100]
)
XBQFYL = 83
XCHWDA = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 55, 78, 98, 87, 101, 101, 107]
)
XEKVKZ = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 52])
XFEFJT = 24
XLSXUJ = 84
XNKMLO = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 54])
XPICXQ = "".join(chr(c) for c in [86, 65, 76, 86, 69])
XQGLRA = 97
XQIEFX = "".join(chr(c) for c in [79, 117, 116, 50, 65])
XSJWMN = "".join(
    chr(c) for c in [70, 105, 108, 116, 67, 80, 79, 84, 65, 99, 116, 84, 101, 109, 112]
)
XTIACQ = 7
XUJUTY = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
XWAJVD = "".join(
    chr(c) for c in [82, 101, 115, 116, 111, 114, 101, 65, 108, 108, 85, 68]
)
XYBQSN = 85
YBQSNQ = "".join(
    chr(c) for c in [66, 114, 78, 98, 83, 101, 116, 116, 105, 110, 103, 115]
)
YEKCWA = "".join(chr(c) for c in [79, 119, 110])
YFCRTF = 36
YGDSBD = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 49]
)
YIYWSK = 67
YKLGQP = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
YLIUXF = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
YLJUIK = 3
YMOUNB = "".join(chr(c) for c in [76, 111])
YNQJYM = "".join(chr(c) for c in [80, 117, 109, 112, 85, 68])
YOUSPB = 53
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YWSKWI = "".join(chr(c) for c in [80, 72])
YXBQFY = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 82, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110]
)
YYLIUX = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZILXWA = 60
ZMJIGY = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
AJVDQL = [LXWAJV, XWAJVD, JVHFTH, WAJVDQ]
DNIBXT = [AIIDNI, IIDNIB, IDNIBX, IVLASS]
EKCWAO = [TYEKCW, YEKCWA]
FEGZUQ = [
    JVHFTH,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    BFEGZU,
]
FJTACC = [FEFJTA, EFJTAC]
FTSIFJ = [SPFTSI, PFTSIF]
FYLJUI = [BQFYLJ, QFYLJU]
HIUSOO = [
    JVHFTH,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    PIPIVL,
]
HUGTYI = [OPHUGT, PHUGTY]
IBXYBQ = [JNIBXY, NIBXYB]
IKJPUN = [AFIKJP, FIKJPU]
INEJNI = [RKINEJ, KINEJN]
IUXFEF = [YYLIUX, YLIUXF, LIUXFE]
IVDNQG = [IYWSKW, YWSKWI, WSKWIV, SKWIVD, KWIVDN, WIVDNQ]
JEUTOP = [JVHFTH, BJEUTO]
JPUNRJ = [
    BMJVHF,
    ICXQIE,
    XQIEFX,
    IEFXQG,
    FXQGLR,
    QGLRAH,
    SOKPHU,
    KPHUOJ,
    HUOJRJ,
    OJRJHI,
    RJHIUS,
    MCBFEG,
    EGZUQE,
    UQEXLS,
]
KLGQPL = [JYKLGQ, YKLGQP]
NQJYMO = [UYNQJY, YNQJYM]
OUNBLK = [YMOUNB, MOUNBL]
PBWJYK = [JVHFTH, SPBWJY, PIPIVL]
PICXQI = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    IVLASS,
    VLASSA,
    LASSAK,
    ASSAKQ,
    SSAKQX,
    SAKQXP,
    AKQXPI,
    KQXPIC,
    QXPICX,
    XPICXQ,
]
POUYNQ = [PQIPOU, QIPOUY, IPOUYN]
PUNRJZ = [BFEGZU]
QLAIID = [VDQLAI, DQLAII]
QPLSPF = [PIPIVL, SPBWJY]
RAHEOC = [
    JVHFTH,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    LRAHEO,
]
SIRYXB = [WBSIRY, BSIRYX]
UNRJZT = []
ZUQEXL = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    BFEGZU,
    VLASSA,
    LASSAK,
    ASSAKQ,
    SSAKQX,
    SAKQXP,
    AKQXPI,
    KQXPIC,
    QXPICX,
    XPICXQ,
]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return XTIACQ

    @property
    def output_keys(self):
        return JPUNRJ

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, PICXQI, None, None, QBMJVH
            ),
            ICXQIE: GeckoEnumStructAccessor(
                self.struct, ICXQIE, CXQIEF, None, PICXQI, None, None, QBMJVH
            ),
            XQIEFX: GeckoEnumStructAccessor(
                self.struct, XQIEFX, QIEFXQ, None, PICXQI, None, None, QBMJVH
            ),
            IEFXQG: GeckoEnumStructAccessor(
                self.struct, IEFXQG, EFXQGL, None, PICXQI, None, None, QBMJVH
            ),
            FXQGLR: GeckoEnumStructAccessor(
                self.struct, FXQGLR, XQGLRA, None, PICXQI, None, None, QBMJVH
            ),
            QGLRAH: GeckoEnumStructAccessor(
                self.struct, QGLRAH, GLRAHE, None, RAHEOC, None, None, QBMJVH
            ),
            AHEOCT: GeckoByteStructAccessor(self.struct, AHEOCT, HEOCTH, QBMJVH),
            EOCTHB: GeckoByteStructAccessor(self.struct, EOCTHB, OCTHBS, QBMJVH),
            CTHBSK: GeckoByteStructAccessor(self.struct, CTHBSK, THBSKS, QBMJVH),
            HBSKSO: GeckoByteStructAccessor(self.struct, HBSKSO, BSKSOK, QBMJVH),
            SKSOKP: GeckoByteStructAccessor(self.struct, SKSOKP, KSOKPH, QBMJVH),
            SOKPHU: GeckoEnumStructAccessor(
                self.struct, SOKPHU, OKPHUO, None, PICXQI, None, None, QBMJVH
            ),
            KPHUOJ: GeckoEnumStructAccessor(
                self.struct, KPHUOJ, PHUOJR, None, PICXQI, None, None, QBMJVH
            ),
            HUOJRJ: GeckoEnumStructAccessor(
                self.struct, HUOJRJ, UOJRJH, None, PICXQI, None, None, QBMJVH
            ),
            OJRJHI: GeckoEnumStructAccessor(
                self.struct, OJRJHI, JRJHIU, None, PICXQI, None, None, QBMJVH
            ),
            RJHIUS: GeckoEnumStructAccessor(
                self.struct, RJHIUS, JHIUSO, None, HIUSOO, None, None, QBMJVH
            ),
            IUSOOQ: GeckoByteStructAccessor(self.struct, IUSOOQ, USOOQN, QBMJVH),
            SOOQNR: GeckoByteStructAccessor(self.struct, SOOQNR, OOQNRS, QBMJVH),
            OQNRSJ: GeckoByteStructAccessor(self.struct, OQNRSJ, QNRSJM, QBMJVH),
            NRSJMC: GeckoByteStructAccessor(self.struct, NRSJMC, RSJMCB, QBMJVH),
            SJMCBF: GeckoByteStructAccessor(self.struct, SJMCBF, JMCBFE, QBMJVH),
            MCBFEG: GeckoEnumStructAccessor(
                self.struct, MCBFEG, CBFEGZ, None, FEGZUQ, None, None, QBMJVH
            ),
            EGZUQE: GeckoEnumStructAccessor(
                self.struct, EGZUQE, GZUQEX, None, ZUQEXL, None, None, QBMJVH
            ),
            UQEXLS: GeckoEnumStructAccessor(
                self.struct, UQEXLS, QEXLSX, None, ZUQEXL, None, None, QBMJVH
            ),
            EXLSXU: GeckoByteStructAccessor(self.struct, EXLSXU, XLSXUJ, QBMJVH),
            LSXUJU: GeckoByteStructAccessor(self.struct, LSXUJU, SXUJUT, QBMJVH),
            XUJUTY: GeckoByteStructAccessor(self.struct, XUJUTY, UJUTYE, QBMJVH),
            JUTYEK: GeckoEnumStructAccessor(
                self.struct, JUTYEK, UTYEKC, KCWAON, EKCWAO, None, KCWAON, QBMJVH
            ),
            CWAONP: GeckoByteStructAccessor(self.struct, CWAONP, WAONPY, QBMJVH),
            AONPYY: GeckoByteStructAccessor(self.struct, AONPYY, ONPYYL, QBMJVH),
            NPYYLI: GeckoEnumStructAccessor(
                self.struct, NPYYLI, PYYLIU, None, IUXFEF, None, None, QBMJVH
            ),
            UXFEFJ: GeckoEnumStructAccessor(
                self.struct, UXFEFJ, XFEFJT, None, FJTACC, None, None, QBMJVH
            ),
            JTACCP: GeckoBoolStructAccessor(
                self.struct, JTACCP, TACCPQ, ACCPQI, QBMJVH
            ),
            CCPQIP: GeckoEnumStructAccessor(
                self.struct, CCPQIP, CPQIPO, None, POUYNQ, None, None, QBMJVH
            ),
            OUYNQJ: GeckoEnumStructAccessor(
                self.struct, OUYNQJ, TACCPQ, QJYMOU, NQJYMO, None, KCWAON, QBMJVH
            ),
            JYMOUN: GeckoEnumStructAccessor(
                self.struct, JYMOUN, TACCPQ, UNBLKX, OUNBLK, None, KCWAON, QBMJVH
            ),
            NBLKXS: GeckoByteStructAccessor(self.struct, NBLKXS, BLKXSJ, QBMJVH),
            LKXSJW: GeckoByteStructAccessor(self.struct, LKXSJW, KXSJWM, QBMJVH),
            XSJWMN: GeckoByteStructAccessor(self.struct, XSJWMN, SJWMNZ, QBMJVH),
            JWMNZM: GeckoByteStructAccessor(self.struct, JWMNZM, WMNZMJ, QBMJVH),
            MNZMJI: GeckoByteStructAccessor(self.struct, MNZMJI, NZMJIG, QBMJVH),
            ZMJIGY: GeckoByteStructAccessor(self.struct, ZMJIGY, MJIGYO, QBMJVH),
            JIGYOU: GeckoByteStructAccessor(self.struct, JIGYOU, IGYOUS, QBMJVH),
            GYOUSP: GeckoByteStructAccessor(self.struct, GYOUSP, YOUSPB, QBMJVH),
            OUSPBW: GeckoEnumStructAccessor(
                self.struct, OUSPBW, USPBWJ, None, PBWJYK, None, None, QBMJVH
            ),
            BWJYKL: GeckoEnumStructAccessor(
                self.struct, BWJYKL, WJYKLG, None, KLGQPL, None, None, QBMJVH
            ),
            LGQPLS: GeckoEnumStructAccessor(
                self.struct, LGQPLS, GQPLSP, None, QPLSPF, None, None, QBMJVH
            ),
            PLSPFT: GeckoEnumStructAccessor(
                self.struct, PLSPFT, LSPFTS, None, FTSIFJ, None, None, QBMJVH
            ),
            TSIFJB: GeckoByteStructAccessor(self.struct, TSIFJB, SIFJBI, QBMJVH),
            IFJBIA: GeckoEnumStructAccessor(
                self.struct, IFJBIA, FJBIAM, None, NQJYMO, None, None, QBMJVH
            ),
            JBIAMJ: GeckoByteStructAccessor(self.struct, JBIAMJ, BIAMJM, QBMJVH),
            IAMJMA: GeckoByteStructAccessor(self.struct, IAMJMA, AMJMAO, QBMJVH),
            MJMAOA: GeckoByteStructAccessor(self.struct, MJMAOA, JMAOAW, QBMJVH),
            MAOAWB: GeckoTempStructAccessor(self.struct, MAOAWB, AOAWBS, QBMJVH),
            OAWBSI: GeckoEnumStructAccessor(
                self.struct, OAWBSI, AWBSIR, KCWAON, SIRYXB, None, KCWAON, QBMJVH
            ),
            IRYXBQ: GeckoEnumStructAccessor(
                self.struct, IRYXBQ, RYXBQF, None, QPLSPF, None, None, QBMJVH
            ),
            YXBQFY: GeckoEnumStructAccessor(
                self.struct, YXBQFY, XBQFYL, YLJUIK, FYLJUI, None, KCWAON, QBMJVH
            ),
            LJUIKF: GeckoBoolStructAccessor(
                self.struct, LJUIKF, JUIKFW, ACCPQI, QBMJVH
            ),
            UIKFWR: GeckoBoolStructAccessor(
                self.struct, UIKFWR, JUIKFW, IKFWRK, QBMJVH
            ),
            KFWRKI: GeckoByteStructAccessor(self.struct, KFWRKI, FWRKIN, QBMJVH),
            WRKINE: GeckoEnumStructAccessor(
                self.struct, WRKINE, XBQFYL, NEJNIB, INEJNI, None, KCWAON, QBMJVH
            ),
            EJNIBX: GeckoEnumStructAccessor(
                self.struct, EJNIBX, XBQFYL, KCWAON, IBXYBQ, None, KCWAON, QBMJVH
            ),
            BXYBQS: GeckoByteStructAccessor(self.struct, BXYBQS, XYBQSN, None),
            YBQSNQ: GeckoByteStructAccessor(self.struct, YBQSNQ, BQSNQL, None),
            QSNQLN: GeckoByteStructAccessor(self.struct, QSNQLN, SNQLNM, None),
            NQLNMH: GeckoByteStructAccessor(self.struct, NQLNMH, QLNMHX, QBMJVH),
            LNMHXE: GeckoByteStructAccessor(self.struct, LNMHXE, NMHXEK, QBMJVH),
            MHXEKV: GeckoByteStructAccessor(self.struct, MHXEKV, HXEKVK, QBMJVH),
            XEKVKZ: GeckoByteStructAccessor(self.struct, XEKVKZ, EKVKZI, QBMJVH),
            KVKZIL: GeckoByteStructAccessor(self.struct, KVKZIL, VKZILX, QBMJVH),
            KZILXW: GeckoBoolStructAccessor(
                self.struct, KZILXW, ZILXWA, QJYMOU, QBMJVH
            ),
            ILXWAJ: GeckoEnumStructAccessor(
                self.struct, ILXWAJ, ZILXWA, NEJNIB, AJVDQL, None, ACCPQI, QBMJVH
            ),
            JVDQLA: GeckoEnumStructAccessor(
                self.struct, JVDQLA, ZILXWA, UNBLKX, QLAIID, None, KCWAON, QBMJVH
            ),
            LAIIDN: GeckoEnumStructAccessor(
                self.struct, LAIIDN, AWBSIR, YLJUIK, DNIBXT, None, ACCPQI, QBMJVH
            ),
            NIBXTI: GeckoBoolStructAccessor(
                self.struct, NIBXTI, AWBSIR, IKFWRK, QBMJVH
            ),
            IBXTIA: GeckoBoolStructAccessor(
                self.struct, IBXTIA, AWBSIR, QJYMOU, QBMJVH
            ),
            BXTIAC: GeckoBoolStructAccessor(
                self.struct, BXTIAC, AWBSIR, XTIACQ, QBMJVH
            ),
            TIACQF: GeckoEnumStructAccessor(
                self.struct, TIACQF, JUIKFW, NEJNIB, PBWJYK, None, ACCPQI, QBMJVH
            ),
            IACQFF: GeckoBoolStructAccessor(
                self.struct, IACQFF, JUIKFW, YLJUIK, QBMJVH
            ),
            ACQFFT: GeckoByteStructAccessor(self.struct, ACQFFT, CQFFTT, QBMJVH),
            QFFTTI: GeckoByteStructAccessor(self.struct, QFFTTI, FFTTID, QBMJVH),
            FTTIDU: GeckoByteStructAccessor(self.struct, FTTIDU, TTIDUB, QBMJVH),
            TIDUBS: GeckoByteStructAccessor(self.struct, TIDUBS, IDUBSS, QBMJVH),
            DUBSSU: GeckoByteStructAccessor(self.struct, DUBSSU, UBSSUH, QBMJVH),
            BSSUHB: GeckoByteStructAccessor(self.struct, BSSUHB, SSUHBV, QBMJVH),
            SUHBVW: GeckoBoolStructAccessor(
                self.struct, SUHBVW, UHBVWV, UNBLKX, QBMJVH
            ),
            HBVWVU: GeckoBoolStructAccessor(
                self.struct, HBVWVU, UHBVWV, KCWAON, QBMJVH
            ),
            BVWVUB: GeckoByteStructAccessor(self.struct, BVWVUB, VWVUBY, QBMJVH),
            WVUBYG: GeckoByteStructAccessor(self.struct, WVUBYG, VUBYGD, QBMJVH),
            UBYGDS: GeckoByteStructAccessor(self.struct, UBYGDS, BYGDSB, QBMJVH),
            YGDSBD: GeckoByteStructAccessor(self.struct, YGDSBD, GDSBDJ, QBMJVH),
            DSBDJQ: GeckoByteStructAccessor(self.struct, DSBDJQ, SBDJQR, QBMJVH),
            BDJQRJ: GeckoByteStructAccessor(self.struct, BDJQRJ, DJQRJJ, QBMJVH),
            JQRJJJ: GeckoByteStructAccessor(self.struct, JQRJJJ, QRJJJV, QBMJVH),
            RJJJVY: GeckoTimeStructAccessor(self.struct, RJJJVY, JJJVYF, QBMJVH),
            JJVYFC: GeckoTimeStructAccessor(self.struct, JJVYFC, JVYFCR, QBMJVH),
            VYFCRT: GeckoTimeStructAccessor(self.struct, VYFCRT, YFCRTF, QBMJVH),
            FCRTFM: GeckoTimeStructAccessor(self.struct, FCRTFM, CRTFMN, QBMJVH),
            RTFMNH: GeckoByteStructAccessor(self.struct, RTFMNH, TFMNHT, QBMJVH),
            FMNHTB: GeckoTimeStructAccessor(self.struct, FMNHTB, MNHTBJ, QBMJVH),
            NHTBJE: GeckoTimeStructAccessor(self.struct, NHTBJE, HTBJEU, QBMJVH),
            TBJEUT: GeckoEnumStructAccessor(
                self.struct, TBJEUT, ZILXWA, ACCPQI, JEUTOP, None, KCWAON, QBMJVH
            ),
            EUTOPH: GeckoBoolStructAccessor(
                self.struct, EUTOPH, ZILXWA, IKFWRK, QBMJVH
            ),
            UTOPHU: GeckoBoolStructAccessor(
                self.struct, UTOPHU, ZILXWA, YLJUIK, QBMJVH
            ),
            TOPHUG: GeckoEnumStructAccessor(
                self.struct, TOPHUG, UTYEKC, UNBLKX, HUGTYI, None, KCWAON, QBMJVH
            ),
            UGTYIY: GeckoBoolStructAccessor(
                self.struct, UGTYIY, UTYEKC, NEJNIB, QBMJVH
            ),
            DAFIKJ: GeckoEnumStructAccessor(
                self.struct, DAFIKJ, XBQFYL, UNBLKX, IKJPUN, None, KCWAON, QBMJVH
            ),
            KJPUNR: GeckoBoolStructAccessor(
                self.struct, KJPUNR, JUIKFW, UNBLKX, QBMJVH
            ),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InXE v57'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
ACQFFT = 8
AHEOCT = "".join(chr(c) for c in [79, 117, 116, 53, 67, 117, 114])
AIIDNI = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        67,
        111,
        108,
        111,
        114,
    ]
)
AJVDQL = "".join(
    chr(c)
    for c in [67, 117, 115, 116, 111, 109, 75, 101, 121, 69, 110, 97, 98, 108, 101, 100]
)
AKQXPI = "".join(chr(c) for c in [79, 117, 116, 51])
AMJMAO = 3
AOAWBS = 6
AONPYY = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
AWBSIR = 23
BDJQRJ = "".join(chr(c) for c in [74, 97, 99, 117, 122, 122, 105])
BFEGZU = "".join(
    chr(c) for c in [70, 105, 108, 116, 80, 49, 68, 117, 114, 79, 110, 108, 121]
)
BJEUTO = "".join(chr(c) for c in [65, 115, 112, 101, 110])
BLKXSJ = 31
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQSNQL = 34
BSIRYX = 8
BSKSOK = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
BSSUHB = "".join(
    chr(c) for c in [69, 110, 100, 108, 101, 115, 115, 80, 111, 111, 108, 115]
)
BVWVUB = "".join(chr(c) for c in [66, 97, 114, 101, 102, 111, 111, 116])
BWJYKL = "".join(chr(c) for c in [78, 105, 103, 104, 116])
BXTIAC = "".join(chr(c) for c in [77, 65, 71, 69, 78, 84, 65])
BXYBQS = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
BYGDSB = "".join(chr(c) for c in [67, 111, 97, 115, 116])
CBFEGZ = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
CCPQIP = 29
CQBMJV = 0
CQFFTT = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        69,
        100,
        105,
        116,
    ]
)
CRTFMN = "".join(
    chr(c) for c in [83, 117, 112, 101, 114, 105, 111, 114, 83, 112, 97, 115]
)
CTHBSK = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
CXQIEF = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
DJQRJJ = "".join(chr(c) for c in [74, 97, 122, 122, 105])
DNIBXT = "".join(chr(c) for c in [71, 82, 69, 69, 78])
DQLAII = "".join(
    chr(c)
    for c in [80, 65, 83, 83, 87, 79, 82, 68, 95, 80, 82, 79, 84, 69, 67, 84, 69, 68]
)
DSBDJQ = "".join(chr(c) for c in [70, 111, 117, 114, 95, 87, 105, 110, 100])
DUBSSU = "".join(chr(c) for c in [71, 101, 110, 101, 114, 105, 99])
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFJTAC = 28
EFXQGL = 36
EGZUQE = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
EJNIBX = 73
EKCWAO = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
EKVKZI = "".join(
    chr(c) for c in [83, 101, 108, 102, 67, 108, 101, 97, 110, 77, 115, 103]
)
EOCTHB = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
EUTOPH = "".join(chr(c) for c in [84, 105, 116, 97, 110, 95, 83, 112, 97, 115])
EXLSXU = "".join(chr(c) for c in [79, 116, 79, 112, 116, 105, 111, 110])
FCRTFM = "".join(chr(c) for c in [83, 117, 110, 114, 105, 115, 101])
FEFJTA = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
FFTTID = "".join(chr(c) for c in [69, 110, 97, 98, 108, 101])
FJBIAM = 74
FJTACC = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
FMNHTB = "".join(
    chr(c) for c in [87, 87, 79, 95, 87, 104, 105, 114, 108, 99, 97, 114, 101]
)
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = 52
FWRKIN = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
FXQGLR = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
FYLJUI = 82
GDSBDJ = "".join(chr(c) for c in [68, 121, 110, 97, 115, 116, 121])
GLRAHE = 38
GQPLSP = "".join(chr(c) for c in [85, 76, 95, 67, 69])
GYOUSP = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
GZUQEX = 27
HBVWVU = "".join(chr(c) for c in [65, 114, 99, 116, 105, 99])
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = 40
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HIUSOO = 56
HTBJEU = "".join(chr(c) for c in [68, 101, 108, 117, 120, 101])
HUGTYI = "".join(
    chr(c) for c in [72, 73, 68, 69, 95, 68, 69, 84, 65, 73, 76, 69, 68, 95, 77, 83, 71]
)
HUOJRJ = 80
HXEKVK = "".join(
    chr(c) for c in [72, 105, 103, 104, 83, 112, 101, 101, 100, 79, 110, 108, 121]
)
IAMJMA = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
IBXTIA = "".join(chr(c) for c in [66, 76, 85, 69])
ICXQIE = 16
IDNIBX = "".join(chr(c) for c in [82, 69, 68])
IDUBSS = 44
IEFXQG = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
IFJBIA = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
IGYOUS = 35
IIDNIB = "".join(chr(c) for c in [79, 70, 70])
IKFWRK = 1
IPIVLA = "".join(chr(c) for c in [79, 51])
IPOUYN = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
IRYXBQ = 10
IUSOOQ = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
IUXFEF = 78
IVDNQG = 57
IVLASS = "".join(chr(c) for c in [72, 84, 82])
IYWSKW = 46
JBIAMJ = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
JEUTOP = "".join(chr(c) for c in [84, 104, 101, 114, 109, 111, 83, 112, 97, 115])
JHIUSO = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
JIGYOU = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
JJJVYF = "".join(chr(c) for c in [77, 97, 114, 113, 117, 105, 115])
JJVYFC = "".join(chr(c) for c in [80, 68, 67])
JMAOAW = 4
JMCBFE = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
JNIBXY = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
JQRJJJ = "".join(chr(c) for c in [76, 65])
JRJHIU = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
JTACCP = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
JUIKFW = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
JUTYEK = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
JVDQLA = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 67, 104, 97, 110, 103, 101]
)
JVHFTH = "".join(chr(c) for c in [78, 65])
JVYFCR = "".join(
    chr(c)
    for c in [80, 114, 101, 109, 105, 117, 109, 95, 76, 101, 105, 115, 117, 114, 101]
)
JYKLGQ = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
JYMOUN = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
KCWAON = 58
KFWRKI = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
KINEJN = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
KLGQPL = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        80,
        104,
        97,
        115,
        101,
        115,
    ]
)
KQXPIC = 14
KSOKPH = "".join(chr(c) for c in [79, 117, 116, 76, 105])
KVKZIL = 4
KXSJWM = 25
KZILXW = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
LAIIDN = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 67, 104, 97, 110, 103, 101]
)
LASSAK = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
LGQPLS = 26
LIUXFE = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
LJUIKF = 72
LKXSJW = "".join(
    chr(c) for c in [70, 108, 111, 119, 68, 101, 116, 101, 99, 116, 111, 114]
)
LNMHXE = 64
LRAHEO = "".join(chr(c) for c in [79, 117, 116, 52, 67, 117, 114])
LSPFTS = "".join(chr(c) for c in [67, 69])
LSXUJU = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
LXWAJV = 5
MAOAWB = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
MCBFEG = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
MHXEKV = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
MJIGYO = 3
MJMAOA = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
MJVHFT = 12
MNHTBJ = "".join(chr(c) for c in [79, 107, 101, 97, 110, 111, 115])
MNZMJI = "".join(chr(c) for c in [73, 110, 116, 111, 80, 105, 112, 105, 110, 103])
MOUNBL = "".join(chr(c) for c in [70])
NBLKXS = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
NEJNIB = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
NHTBJE = "".join(chr(c) for c in [67, 108, 101, 97, 114, 119, 97, 116, 101, 114])
NIBXTI = "".join(chr(c) for c in [89, 69, 76, 76, 79, 87])
NIBXYB = "".join(chr(c) for c in [83, 108, 97, 118, 101])
NMHXEK = "".join(
    chr(c)
    for c in [80, 117, 109, 112, 49, 85, 115, 101, 114, 65, 99, 99, 101, 115, 115]
)
NPYYLI = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
NQJYMO = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
NRSJMC = 2
NZMJIG = "".join(chr(c) for c in [73, 110, 116, 111, 84, 117, 98])
OAWBSI = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114, 50])
OCTHBS = 42
OJRJHI = 54
OKPHUO = "".join(chr(c) for c in [76, 73])
ONPYYL = 60
OOQNRS = "".join(chr(c) for c in [79, 119, 110])
OPHUGT = "".join(
    chr(c) for c in [73, 110, 102, 111, 77, 115, 103, 67, 111, 110, 102, 105, 103]
)
OUNBLK = "".join(chr(c) for c in [67])
OUSPBW = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
PBWJYK = 70
PFTSIF = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
PHUGTY = 45
PHUOJR = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
PICXQI = "".join(chr(c) for c in [79, 117, 116, 53])
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = "".join(chr(c) for c in [85, 76])
POUYNQ = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
PQIPOU = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
PYYLIU = 61
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QFFTTI = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101])
QFYLJU = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
QGLRAH = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
QIPOUY = 30
QJYMOU = 1
QLNMHX = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
QNRSJM = 0
QPLSPF = 51
QRJJJV = "".join(chr(c) for c in [80, 114, 111, 95, 70, 108, 111, 97, 116])
QSNQLN = "".join(chr(c) for c in [65, 109, 80, 109])
QXPICX = "".join(chr(c) for c in [79, 117, 116, 52])
RAHEOC = 39
RJHIUS = 55
RJJJVY = "".join(chr(c) for c in [77, 65, 65, 88])
RKINEJ = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
RSJMCB = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
RTFMNH = "".join(
    chr(c) for c in [83, 112, 97, 95, 73, 110, 100, 117, 115, 116, 114, 105, 101, 115]
)
RYXBQF = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
SAKQXP = 13
SBDJQR = "".join(chr(c) for c in [72, 111, 116, 115, 112, 114, 105, 110, 103])
SIFJBI = 53
SIRYXB = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
SJMCBF = 32
SJWMNZ = "".join(
    chr(c) for c in [78, 111, 116, 73, 110, 115, 116, 97, 108, 108, 101, 100]
)
SKSOKP = 41
SNQLNM = "".join(chr(c) for c in [50, 52, 104])
SOKPHU = 79
SOOQNR = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
SPBWJY = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
SSAKQX = "".join(chr(c) for c in [79, 117, 116, 50])
SSUHBV = "".join(chr(c) for c in [87, 101, 108, 108, 105, 115])
SUHBVW = "".join(chr(c) for c in [65, 108, 112, 115])
SXUJUT = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
TBJEUT = "".join(chr(c) for c in [73, 100, 111, 108])
TFMNHT = "".join(chr(c) for c in [86, 105, 107, 105, 110, 103])
THBSKS = 17
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = "".join(chr(c) for c in [87, 72, 73, 84, 69])
TIDUBS = "".join(chr(c) for c in [67, 117, 115, 116, 111, 109, 101, 114, 73, 68])
TSIFJB = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
TTIDUB = 7
TYEKCW = "".join(chr(c) for c in [72, 105])
TYIYWS = "".join(
    chr(c)
    for c in [
        76,
        111,
        119,
        101,
        114,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
        77,
        101,
        110,
        117,
    ]
)
UBSSUH = "".join(chr(c) for c in [72, 121, 100, 114, 111, 112, 111, 111, 108])
UBYGDS = "".join(chr(c) for c in [66, 117, 108, 108, 102, 114, 111, 103])
UGTYIY = "".join(chr(c) for c in [83, 72, 79, 87, 95, 65, 76, 76, 95, 77, 83, 71])
UHBVWV = "".join(chr(c) for c in [65, 114, 116, 101, 115, 105, 97, 110])
UIKFWR = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
UOJRJH = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
UQEXLS = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
USOOQN = 81
USPBWJ = 68
UTOPHU = "".join(chr(c) for c in [73, 98, 101, 114, 83, 112, 97])
UTYEKC = "".join(chr(c) for c in [76, 111])
UXFEFJ = "".join(chr(c) for c in [80, 49])
UYNQJY = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
VDQLAI = "".join(
    chr(c) for c in [78, 79, 95, 82, 69, 83, 84, 82, 73, 67, 84, 73, 79, 78]
)
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
VLASSA = "".join(chr(c) for c in [])
VUBYGD = "".join(
    chr(c)
    for c in [76, 101, 105, 115, 117, 114, 101, 95, 80, 114, 111, 100, 95, 73, 110, 100]
)
VWVUBY = "".join(chr(c) for c in [66, 101, 97, 99, 104, 99, 111, 109, 98, 101, 114])
VYFCRT = "".join(chr(c) for c in [83, 116, 114, 111, 110, 103])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAJVDQ = 43
WAONPY = 59
WBSIRY = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
WMNZMJ = "".join(
    chr(c) for c in [80, 114, 111, 98, 101, 76, 111, 99, 97, 116, 105, 111, 110]
)
WRKINE = 76
WSKWIV = 47
WVUBYG = "".join(chr(c) for c in [66, 101, 108, 108, 97, 103, 105, 111])
XBQFYL = "".join(
    chr(c) for c in [79, 85, 84, 83, 73, 68, 69, 95, 70, 73, 76, 84, 69, 82]
)
XLSXUJ = 57
XPICXQ = 15
XQGLRA = 37
XQIEFX = 18
XSJWMN = "".join(chr(c) for c in [105, 110, 70, 108, 111])
XTIACQ = "".join(chr(c) for c in [67, 89, 65, 78])
XUJUTY = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
XWAJVD = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        84,
        104,
        101,
        114,
        97,
        112,
        121,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
XYBQSN = 75
YBQSNQ = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
YFCRTF = "".join(chr(c) for c in [83, 117, 110, 114, 97, 110, 115])
YGDSBD = "".join(
    chr(c) for c in [68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 111, 110, 101]
)
YIYWSK = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
)
YKLGQP = 77
YLIUXF = 62
YLJUIK = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
YMOUNB = 33
YNQJYM = 63
YOUSPB = 66
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YWSKWI = "".join(
    chr(c)
    for c in [
        68,
        101,
        97,
        108,
        101,
        114,
        76,
        111,
        99,
        107,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
YXBQFY = 71
YYLIUX = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZILXWA = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
ZUQEXL = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
ASSAKQ = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    LASSAK,
]
BIAMJM = [IPOUYN, JBIAMJ]
BQFYLJ = [JVHFTH, ZUQEXL, XBQFYL]
CPQIPO = [PIPIVL, UXFEFJ]
FEGZUQ = [JMCBFE, MCBFEG, CBFEGZ, BFEGZU]
FTTIDU = [QFFTTI, FFTTID]
GTYIYW = [HUGTYI, UGTYIY, VLASSA, VLASSA]
HBSKSO = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIPIVL,
]
IACQFF = [IIDNIB, IDNIBX, DNIBXT, NIBXTI, IBXTIA, BXTIAC, XTIACQ, TIACQF]
IBXYBQ = [VLASSA, JNIBXY, NIBXYB]
ILXWAJ = [KZILXW, ZILXWA]
INEJNI = [RKINEJ, KINEJN]
JWMNZM = [XSJWMN, SJWMNZ]
KPHUOJ = [
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    OKPHUO,
]
KWIVDN = [OKPHUO]
NQLNMH = [JVHFTH, QSNQLN, SNQLNM]
OQNRSJ = [SOOQNR, OOQNRS]
OUYNQJ = [IPOUYN, POUYNQ]
QEXLSX = [ZUQEXL, UQEXLS]
QIEFXQ = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    IVLASS,
]
QLAIID = [VDQLAI, DQLAII]
SKWIVD = [BMJVHF, SSAKQX, AKQXPI, QXPICX, PICXQI, CXQIEF, CTHBSK, KSOKPH]
SPFTSI = [PLSPFT, LSPFTS]
TACCPQ = [FJTACC, JTACCP]
TOPHUG = [
    DUBSSU,
    UBSSUH,
    BSSUHB,
    SSUHBV,
    SUHBVW,
    UHBVWV,
    HBVWVU,
    BVWVUB,
    VWVUBY,
    WVUBYG,
    VUBYGD,
    UBYGDS,
    BYGDSB,
    YGDSBD,
    GDSBDJ,
    DSBDJQ,
    SBDJQR,
    BDJQRJ,
    DJQRJJ,
    JQRJJJ,
    QRJJJV,
    RJJJVY,
    JJJVYF,
    JJVYFC,
    JVYFCR,
    VYFCRT,
    YFCRTF,
    FCRTFM,
    CRTFMN,
    RTFMNH,
    TFMNHT,
    FMNHTB,
    MNHTBJ,
    NHTBJE,
    HTBJEU,
    TBJEUT,
    BJEUTO,
    JEUTOP,
    EUTOPH,
    UTOPHU,
]
UJUTYE = [LSXUJU, SXUJUT, XUJUTY]
UNBLKX = [MOUNBL, OUNBLK]
WIVDNQ = []
WJYKLG = [IPOUYN, BWJYKL]
XEKVKZ = [MHXEKV, HXEKVK]
XFEFJT = [JVHFTH, UXFEFJ, PIPIVL]
YEKCWA = [UTYEKC, TYEKCW]
ZMJIGY = [MNZMJI, NZMJIG]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return IVDNQG

    @property
    def output_keys(self):
        return SKWIVD

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, ASSAKQ, None, None, QBMJVH
            ),
            SSAKQX: GeckoEnumStructAccessor(
                self.struct, SSAKQX, SAKQXP, None, ASSAKQ, None, None, QBMJVH
            ),
            AKQXPI: GeckoEnumStructAccessor(
                self.struct, AKQXPI, KQXPIC, None, ASSAKQ, None, None, QBMJVH
            ),
            QXPICX: GeckoEnumStructAccessor(
                self.struct, QXPICX, XPICXQ, None, ASSAKQ, None, None, QBMJVH
            ),
            PICXQI: GeckoEnumStructAccessor(
                self.struct, PICXQI, ICXQIE, None, ASSAKQ, None, None, QBMJVH
            ),
            CXQIEF: GeckoEnumStructAccessor(
                self.struct, CXQIEF, XQIEFX, None, QIEFXQ, None, None, QBMJVH
            ),
            IEFXQG: GeckoByteStructAccessor(self.struct, IEFXQG, EFXQGL, QBMJVH),
            FXQGLR: GeckoByteStructAccessor(self.struct, FXQGLR, XQGLRA, QBMJVH),
            QGLRAH: GeckoByteStructAccessor(self.struct, QGLRAH, GLRAHE, QBMJVH),
            LRAHEO: GeckoByteStructAccessor(self.struct, LRAHEO, RAHEOC, QBMJVH),
            AHEOCT: GeckoByteStructAccessor(self.struct, AHEOCT, HEOCTH, QBMJVH),
            EOCTHB: GeckoByteStructAccessor(self.struct, EOCTHB, OCTHBS, QBMJVH),
            CTHBSK: GeckoEnumStructAccessor(
                self.struct, CTHBSK, THBSKS, None, HBSKSO, None, None, QBMJVH
            ),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, QBMJVH),
            KSOKPH: GeckoEnumStructAccessor(
                self.struct, KSOKPH, SOKPHU, None, KPHUOJ, None, None, None
            ),
            PHUOJR: GeckoByteStructAccessor(self.struct, PHUOJR, HUOJRJ, None),
            UOJRJH: GeckoByteStructAccessor(self.struct, UOJRJH, OJRJHI, QBMJVH),
            JRJHIU: GeckoByteStructAccessor(self.struct, JRJHIU, RJHIUS, QBMJVH),
            JHIUSO: GeckoByteStructAccessor(self.struct, JHIUSO, HIUSOO, QBMJVH),
            IUSOOQ: GeckoEnumStructAccessor(
                self.struct, IUSOOQ, USOOQN, QNRSJM, OQNRSJ, None, NRSJMC, QBMJVH
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, SJMCBF, None, FEGZUQ, None, None, QBMJVH
            ),
            EGZUQE: GeckoEnumStructAccessor(
                self.struct, EGZUQE, GZUQEX, None, QEXLSX, None, None, QBMJVH
            ),
            EXLSXU: GeckoEnumStructAccessor(
                self.struct, EXLSXU, XLSXUJ, None, UJUTYE, None, None, QBMJVH
            ),
            JUTYEK: GeckoEnumStructAccessor(
                self.struct, JUTYEK, USOOQN, NRSJMC, YEKCWA, None, NRSJMC, QBMJVH
            ),
            EKCWAO: GeckoByteStructAccessor(self.struct, EKCWAO, KCWAON, QBMJVH),
            CWAONP: GeckoByteStructAccessor(self.struct, CWAONP, WAONPY, QBMJVH),
            AONPYY: GeckoByteStructAccessor(self.struct, AONPYY, ONPYYL, QBMJVH),
            NPYYLI: GeckoByteStructAccessor(self.struct, NPYYLI, PYYLIU, QBMJVH),
            YYLIUX: GeckoByteStructAccessor(self.struct, YYLIUX, YLIUXF, QBMJVH),
            LIUXFE: GeckoEnumStructAccessor(
                self.struct, LIUXFE, IUXFEF, None, XFEFJT, None, None, QBMJVH
            ),
            FEFJTA: GeckoEnumStructAccessor(
                self.struct, FEFJTA, EFJTAC, None, TACCPQ, None, None, QBMJVH
            ),
            ACCPQI: GeckoEnumStructAccessor(
                self.struct, ACCPQI, CCPQIP, None, CPQIPO, None, None, QBMJVH
            ),
            PQIPOU: GeckoEnumStructAccessor(
                self.struct, PQIPOU, QIPOUY, None, OUYNQJ, None, None, QBMJVH
            ),
            UYNQJY: GeckoByteStructAccessor(self.struct, UYNQJY, YNQJYM, QBMJVH),
            NQJYMO: GeckoTempStructAccessor(self.struct, NQJYMO, QJYMOU, QBMJVH),
            JYMOUN: GeckoEnumStructAccessor(
                self.struct, JYMOUN, YMOUNB, None, UNBLKX, None, None, QBMJVH
            ),
            NBLKXS: GeckoEnumStructAccessor(
                self.struct, NBLKXS, BLKXSJ, None, CPQIPO, None, None, QBMJVH
            ),
            LKXSJW: GeckoEnumStructAccessor(
                self.struct, LKXSJW, KXSJWM, None, JWMNZM, None, None, QBMJVH
            ),
            WMNZMJ: GeckoEnumStructAccessor(
                self.struct, WMNZMJ, USOOQN, MJIGYO, ZMJIGY, None, NRSJMC, QBMJVH
            ),
            JIGYOU: GeckoByteStructAccessor(self.struct, JIGYOU, IGYOUS, QBMJVH),
            GYOUSP: GeckoTempStructAccessor(self.struct, GYOUSP, YOUSPB, QBMJVH),
            OUSPBW: GeckoTempStructAccessor(self.struct, OUSPBW, USPBWJ, QBMJVH),
            SPBWJY: GeckoEnumStructAccessor(
                self.struct, SPBWJY, PBWJYK, None, WJYKLG, None, None, QBMJVH
            ),
            JYKLGQ: GeckoByteStructAccessor(self.struct, JYKLGQ, YKLGQP, QBMJVH),
            KLGQPL: GeckoByteStructAccessor(self.struct, KLGQPL, LGQPLS, QBMJVH),
            GQPLSP: GeckoEnumStructAccessor(
                self.struct, GQPLSP, QPLSPF, None, SPFTSI, None, None, QBMJVH
            ),
            PFTSIF: GeckoByteStructAccessor(self.struct, PFTSIF, FTSIFJ, QBMJVH),
            TSIFJB: GeckoByteStructAccessor(self.struct, TSIFJB, SIFJBI, QBMJVH),
            IFJBIA: GeckoEnumStructAccessor(
                self.struct, IFJBIA, FJBIAM, None, BIAMJM, None, None, QBMJVH
            ),
            IAMJMA: GeckoByteStructAccessor(self.struct, IAMJMA, AMJMAO, QBMJVH),
            MJMAOA: GeckoTimeStructAccessor(self.struct, MJMAOA, JMAOAW, QBMJVH),
            MAOAWB: GeckoTimeStructAccessor(self.struct, MAOAWB, AOAWBS, QBMJVH),
            OAWBSI: GeckoTimeStructAccessor(self.struct, OAWBSI, AWBSIR, QBMJVH),
            WBSIRY: GeckoTimeStructAccessor(self.struct, WBSIRY, BSIRYX, QBMJVH),
            SIRYXB: GeckoTimeStructAccessor(self.struct, SIRYXB, IRYXBQ, QBMJVH),
            RYXBQF: GeckoEnumStructAccessor(
                self.struct, RYXBQF, YXBQFY, None, BQFYLJ, None, None, QBMJVH
            ),
            QFYLJU: GeckoBoolStructAccessor(
                self.struct, QFYLJU, FYLJUI, QNRSJM, QBMJVH
            ),
            YLJUIK: GeckoBoolStructAccessor(
                self.struct, YLJUIK, LJUIKF, NRSJMC, QBMJVH
            ),
            JUIKFW: GeckoBoolStructAccessor(
                self.struct, JUIKFW, LJUIKF, QNRSJM, QBMJVH
            ),
            UIKFWR: GeckoBoolStructAccessor(
                self.struct, UIKFWR, LJUIKF, IKFWRK, QBMJVH
            ),
            KFWRKI: GeckoBoolStructAccessor(
                self.struct, KFWRKI, LJUIKF, MJIGYO, QBMJVH
            ),
            FWRKIN: GeckoEnumStructAccessor(
                self.struct, FWRKIN, WRKINE, None, INEJNI, None, None, QBMJVH
            ),
            NEJNIB: GeckoEnumStructAccessor(
                self.struct, NEJNIB, EJNIBX, None, IBXYBQ, None, None, QBMJVH
            ),
            BXYBQS: GeckoByteStructAccessor(self.struct, BXYBQS, XYBQSN, QBMJVH),
            YBQSNQ: GeckoEnumStructAccessor(
                self.struct, YBQSNQ, BQSNQL, None, NQLNMH, None, None, QBMJVH
            ),
            QLNMHX: GeckoWordStructAccessor(self.struct, QLNMHX, LNMHXE, QBMJVH),
            NMHXEK: GeckoEnumStructAccessor(
                self.struct, NMHXEK, USOOQN, IKFWRK, XEKVKZ, None, NRSJMC, QBMJVH
            ),
            EKVKZI: GeckoBoolStructAccessor(
                self.struct, EKVKZI, USOOQN, KVKZIL, QBMJVH
            ),
            VKZILX: GeckoEnumStructAccessor(
                self.struct, VKZILX, USOOQN, LXWAJV, ILXWAJ, None, NRSJMC, QBMJVH
            ),
            XWAJVD: GeckoBoolStructAccessor(
                self.struct, XWAJVD, WAJVDQ, QNRSJM, QBMJVH
            ),
            AJVDQL: GeckoBoolStructAccessor(
                self.struct, AJVDQL, WAJVDQ, IKFWRK, QBMJVH
            ),
            JVDQLA: GeckoEnumStructAccessor(
                self.struct, JVDQLA, WAJVDQ, NRSJMC, QLAIID, None, NRSJMC, QBMJVH
            ),
            LAIIDN: GeckoEnumStructAccessor(
                self.struct, LAIIDN, WAJVDQ, MJIGYO, QLAIID, None, NRSJMC, QBMJVH
            ),
            AIIDNI: GeckoEnumStructAccessor(
                self.struct, AIIDNI, WAJVDQ, KVKZIL, IACQFF, None, ACQFFT, QBMJVH
            ),
            CQFFTT: GeckoEnumStructAccessor(
                self.struct, CQFFTT, WAJVDQ, TTIDUB, FTTIDU, None, NRSJMC, QBMJVH
            ),
            OPHUGT: GeckoEnumStructAccessor(
                self.struct, OPHUGT, PHUGTY, NRSJMC, GTYIYW, None, KVKZIL, QBMJVH
            ),
            TYIYWS: GeckoBoolStructAccessor(
                self.struct, TYIYWS, PHUGTY, KVKZIL, QBMJVH
            ),
            YIYWSK: GeckoByteStructAccessor(self.struct, YIYWSK, IYWSKW, QBMJVH),
            YWSKWI: GeckoBoolStructAccessor(
                self.struct, YWSKWI, WSKWIV, QNRSJM, QBMJVH
            ),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InXM v3'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = 5
ACQFFT = 99
AFIKJP = "".join(chr(c) for c in [65, 109, 80, 109])
AJVDQL = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 56, 78, 98, 87, 101, 101, 107]
)
AKQXPI = "".join(chr(c) for c in [84, 118, 76, 105, 102, 116])
AMJMAO = 55
AOAWBS = 77
AONPYY = 41
ASSAKQ = "".join(chr(c) for c in [70, 98, 77, 116, 114])
AWBSIR = 72
BDJQRJ = 30
BFEGZU = 211
BIAMJM = 53
BJEUTO = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        99,
        116,
        105,
        118,
        101,
        79,
        110,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        84,
    ]
)
BLKXSJ = 62
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49, 65])
BQFYLJ = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
BQSNQL = 84
BSIRYX = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
BSKSOK = "".join(
    chr(c) for c in [79, 117, 116, 50, 66, 67, 117, 114, 114, 101, 110, 116]
)
BSSUHB = 104
BVWVUB = "".join(
    chr(c)
    for c in [
        67,
        69,
        95,
        74,
        109,
        112,
        49,
        95,
        52,
        95,
        73,
        110,
        115,
        116,
        97,
        108,
        108,
        101,
        100,
    ]
)
BWJYKL = 68
BXTIAC = 97
BXYBQS = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 53])
BYGDSB = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 77, 101, 110, 117])
CBFEGZ = "".join(chr(c) for c in [79, 117, 116, 73, 79, 50])
CCPQIP = "".join(
    chr(c) for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121]
)
CHWDAF = "".join(chr(c) for c in [67, 80, 80, 87, 77, 68, 101, 102, 97, 117, 108, 116])
CPQIPO = "".join(chr(c) for c in [65, 110, 121, 85, 68])
CQBMJV = 1
CQFFTT = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 49])
CRTFMN = "".join(chr(c) for c in [67, 97, 110, 99, 101, 108])
CTHBSK = 221
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = 73
CXQIEF = "".join(chr(c) for c in [79, 117, 116, 49, 66])
DAFIKJ = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
DJQRJJ = "".join(chr(c) for c in [78, 111, 65, 99, 116, 105, 111, 110])
DNIBXT = "".join(chr(c) for c in [50, 51, 48, 86, 65, 67])
DNQGVU = "".join(
    chr(c) for c in [86, 83, 80, 70, 105, 108, 116, 101, 114, 83, 112, 101, 101, 100]
)
DQLAII = 95
DUBSSU = 103
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFJTAC = 4
EFXQGL = "".join(chr(c) for c in [79, 117, 116, 50, 66])
EGZUQE = 212
EJNIBX = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 51])
EKCWAO = 2
EKVKZI = 89
ELHBQN = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
EOCTHB = 220
EUTOPH = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        70,
        111,
        114,
        99,
        101,
        79,
        70,
        70,
        79,
        112,
        116,
        105,
        111,
        110,
    ]
)
EXLSXU = "".join(
    chr(c) for c in [70, 105, 98, 101, 114, 84, 105, 109, 101, 79, 117, 116]
)
FCRTFM = "".join(
    chr(c)
    for c in [81, 117, 105, 101, 116, 65, 99, 116, 105, 111, 110, 79, 110, 85, 68]
)
FEFJTA = "".join(
    chr(c) for c in [70, 105, 108, 116, 79, 84, 79, 112, 116, 105, 111, 110]
)
FEGZUQ = "".join(chr(c) for c in [79, 117, 116, 73, 79, 52])
FFTTID = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 50])
FIKJPU = "".join(chr(c) for c in [50, 52, 104])
FJBIAM = 51
FJTACC = "".join(chr(c) for c in [67, 80, 65, 108, 119, 97, 121, 115, 79, 78])
FMNHTB = "".join(chr(c) for c in [70, 97, 110, 80, 117, 109, 112])
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = 43
FTTIDU = 101
FWRKIN = "".join(chr(c) for c in [67, 104, 97, 110, 103, 101, 87, 97, 116, 101, 114])
FXQGLR = 203
GDSBDJ = "".join(
    chr(c) for c in [78, 111, 116, 65, 118, 97, 105, 108, 97, 98, 108, 101]
)
GLRAHE = "".join(chr(c) for c in [79, 117, 116, 72, 101, 97, 116, 101, 114])
GQPLSP = 59
GSELHB = "".join(
    chr(c) for c in [69, 120, 116, 80, 114, 111, 98, 101, 69, 110, 97, 98, 108, 101]
)
GTYIYW = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        83,
        101,
        116,
        70,
        111,
        114,
        99,
        101,
        79,
        102,
        102,
        84,
        101,
        109,
        112,
        65,
        100,
        99,
    ]
)
GVUNXN = 26
GZUQEX = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
HBQNRX = "".join(chr(c) for c in [70])
HBSKSO = 222
HBVWVU = "".join(
    chr(c)
    for c in [
        67,
        69,
        95,
        74,
        109,
        112,
        49,
        95,
        51,
        95,
        73,
        110,
        115,
        116,
        97,
        108,
        108,
        101,
        100,
    ]
)
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = "".join(
    chr(c) for c in [79, 117, 116, 49, 65, 67, 117, 114, 114, 101, 110, 116]
)
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HIUSOO = 225
HUGTYI = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        99,
        116,
        105,
        118,
        101,
        68,
        101,
        108,
        97,
        121,
        65,
        102,
        116,
        101,
        114,
        80,
        117,
        109,
        112,
        82,
        117,
        110,
    ]
)
HUOJRJ = 206
HWDAFI = 22
HXEKVK = 88
IACQFF = "".join(chr(c) for c in [66, 114, 83, 101, 116, 73, 110, 100, 101, 120])
IAMJMA = "".join(chr(c) for c in [79, 110, 122, 101, 110, 70, 114, 101, 113])
IBXTIA = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
IBXYBQ = 82
IDNIBX = "".join(chr(c) for c in [50, 52, 48, 86, 97, 99])
IDUBSS = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 52])
IEFXQG = 202
IFJBIA = "".join(chr(c) for c in [79, 110, 122, 101, 110, 83, 116, 97, 114, 116])
IGYOUS = "".join(chr(c) for c in [80, 49])
IIDNIB = "".join(chr(c) for c in [76, 105, 110, 101, 86, 111, 108, 116, 97, 103, 101])
IJUGSE = "".join(chr(c) for c in [78, 111])
IKFWRK = "".join(chr(c) for c in [80, 72])
ILXWAJ = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 54, 78, 98, 87, 101, 101, 107]
)
INEJNI = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 50])
IPIVLA = "".join(chr(c) for c in [79, 51])
IPOUYN = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        67,
        80,
        79,
        84,
        76,
        105,
        109,
        105,
        116,
        79,
        112,
        116,
        105,
        111,
        110,
    ]
)
IRYXBQ = "".join(chr(c) for c in [65, 99, 116, 105, 118, 101])
IUSOOQ = "".join(
    chr(c) for c in [79, 117, 116, 53, 65, 67, 117, 114, 114, 101, 110, 116]
)
IUXFEF = 40
IVDNQG = "".join(
    chr(c)
    for c in [86, 83, 80, 67, 104, 101, 99, 107, 102, 108, 111, 83, 112, 101, 101, 100]
)
IVLASS = "".join(chr(c) for c in [72, 84, 82])
IYWSKW = 38
JBIAMJ = "".join(chr(c) for c in [79, 110, 122, 101, 110, 68, 117, 114])
JEUTOP = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        99,
        116,
        105,
        118,
        101,
        79,
        110,
        80,
        117,
        109,
        112,
        82,
        117,
        110,
    ]
)
JHIUSO = "".join(
    chr(c) for c in [79, 117, 116, 52, 65, 67, 117, 114, 114, 101, 110, 116]
)
JIGYOU = "".join(chr(c) for c in [78, 79, 78, 69])
JJJVYF = "".join(
    chr(c)
    for c in [85, 68, 65, 99, 116, 105, 111, 110, 79, 110, 81, 117, 105, 101, 116]
)
JJVYFC = "".join(chr(c) for c in [73, 103, 110, 111, 114, 101, 85, 68])
JMAOAW = 75
JMCBFE = 210
JNIBXY = 81
JPUNRJ = "".join(
    chr(c)
    for c in [
        65,
        117,
        120,
        50,
        65,
        115,
        83,
        112,
        101,
        97,
        107,
        101,
        114,
        76,
        105,
        102,
        116,
        101,
        114,
    ]
)
JQRJJJ = "".join(
    chr(c) for c in [70, 111, 114, 99, 101, 77, 97, 120, 80, 111, 119, 101, 114]
)
JRJHIU = "".join(chr(c) for c in [79, 117, 116, 55, 65])
JTACCP = 3
JUGSEL = "".join(
    chr(c) for c in [70, 117, 108, 108, 80, 111, 119, 101, 114, 79, 110, 108, 121]
)
JUIKFW = 79
JUTYEK = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
JVDQLA = 94
JVHFTH = "".join(chr(c) for c in [78, 65])
JVYFCR = "".join(
    chr(c)
    for c in [
        69,
        120,
        105,
        116,
        81,
        117,
        105,
        101,
        116,
        65,
        110,
        100,
        82,
        101,
        115,
        116,
        111,
        114,
        101,
        65,
        108,
        108,
        85,
        68,
    ]
)
JWMNZM = "".join(
    chr(c) for c in [70, 105, 108, 116, 67, 80, 79, 84, 77, 97, 120, 68, 117, 114]
)
JYKLGQ = 69
JYMOUN = "".join(chr(c) for c in [72, 105])
JZTATD = "".join(chr(c) for c in [79, 110, 80, 51])
KCWAON = "".join(
    chr(c) for c in [81, 117, 105, 101, 116, 84, 105, 109, 101, 79, 117, 116]
)
KFWRKI = "".join(chr(c) for c in [67, 104, 101, 99, 107, 71, 70, 67, 73])
KJPUNR = "".join(
    chr(c) for c in [65, 117, 120, 49, 65, 115, 84, 86, 76, 105, 102, 116, 101, 114]
)
KLGQPL = 70
KMLOIJ = 29
KPHUOJ = 205
KQXPIC = "".join(chr(c) for c in [83, 112, 76, 105, 102, 116])
KSOKPH = "".join(
    chr(c) for c in [79, 117, 116, 51, 65, 67, 117, 114, 114, 101, 110, 116]
)
KVKZIL = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 52, 78, 98, 87, 101, 101, 107]
)
KWIVDN = 23
KXSJWM = 63
KZILXW = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 53, 78, 98, 87, 101, 101, 107]
)
LAIIDN = "".join(chr(c) for c in [53, 48, 72, 90])
LASSAK = "".join(chr(c) for c in [70, 65, 78])
LGQPLS = "".join(chr(c) for c in [83, 97, 110, 105, 76, 101, 118, 101, 108])
LHBQNR = "".join(chr(c) for c in [67])
LIUXFE = "".join(chr(c) for c in [67, 108, 101, 97, 110, 80, 49])
LJUIKF = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 49])
LKXSJW = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 67, 80, 79, 84, 68, 101, 97, 100, 98, 97, 110, 100]
)
LNMHXE = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 49, 78, 98, 87, 101, 101, 107]
)
LRAHEO = 209
LSPFTS = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
LSXUJU = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
LXWAJV = 92
MAOAWB = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 111, 112])
MHXEKV = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 50, 78, 98, 87, 101, 101, 107]
)
MJIGYO = 67
MJMAOA = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
MJVHFT = 200
MLOIJU = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
MNHTBJ = 31
MNZMJI = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
MOUNBL = 0
NBLKXS = "".join(
    chr(c) for c in [70, 105, 108, 116, 67, 80, 79, 84, 65, 99, 116, 84, 101, 109, 112]
)
NEJNIB = 80
NHTBJE = "".join(chr(c) for c in [78, 111, 110, 101])
NIBXYB = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 52])
NKMLOI = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 51]
)
NMHXEK = 87
NPYYLI = "".join(chr(c) for c in [78, 111, 116, 85, 115, 101, 100, 49])
NQGVUN = 25
NQJYMO = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
NQLNMH = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 56])
NRJZTA = "".join(chr(c) for c in [79, 110, 80, 49])
NRSJMC = "".join(
    chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114, 114, 101, 110, 116]
)
NRXCHW = 32
NXNKML = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 50]
)
NZMJIG = 66
OAWBSI = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
OCTHBS = "".join(
    chr(c) for c in [79, 117, 116, 49, 66, 67, 117, 114, 114, 101, 110, 116]
)
OIJUGS = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 82, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110]
)
OJRJHI = 207
OKPHUO = "".join(chr(c) for c in [79, 117, 116, 52, 65])
ONPYYL = "".join(chr(c) for c in [83, 116, 97, 114, 116, 68, 117, 114, 70, 114, 101])
OOQNRS = 227
OPHUGT = "".join(
    chr(c)
    for c in [70, 97, 110, 67, 108, 114, 65, 79, 84, 84, 101, 109, 112, 65, 100, 99]
)
OQNRSJ = "".join(
    chr(c) for c in [79, 117, 116, 55, 65, 67, 117, 114, 114, 101, 110, 116]
)
OUNBLK = "".join(chr(c) for c in [70, 105, 108, 116, 77, 105, 110, 68, 117, 114])
OUSPBW = "".join(
    chr(c) for c in [79, 51, 68, 117, 114, 105, 110, 103, 70, 105, 108, 116]
)
OUYNQJ = "".join(
    chr(c)
    for c in [
        76,
        105,
        109,
        105,
        116,
        101,
        100,
        73,
        102,
        83,
        80,
        66,
        101,
        108,
        111,
        119,
        57,
        53,
        70,
    ]
)
PBWJYK = "".join(
    chr(c) for c in [79, 51, 70, 105, 108, 116, 101, 114, 68, 101, 108, 97, 121]
)
PFTSIF = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
PHUGTY = 35
PHUOJR = "".join(chr(c) for c in [79, 117, 116, 53, 65])
PICXQI = "".join(chr(c) for c in [86, 65, 76, 86, 69])
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = 60
POUYNQ = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
PQIPOU = "".join(chr(c) for c in [80, 117, 109, 112, 85, 68])
PUNRJZ = "".join(chr(c) for c in [65, 117, 120, 50, 65, 115, 79, 110, 122, 101, 110])
PYYLIU = "".join(chr(c) for c in [78, 111, 116, 85, 115, 101, 100, 50])
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = 18
QFFTTI = 100
QFYLJU = "".join(
    chr(c)
    for c in [78, 101, 120, 116, 70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121]
)
QGLRAH = 204
QGVUNX = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 48]
)
QIEFXQ = "".join(chr(c) for c in [79, 117, 116, 50, 65])
QJYMOU = "".join(chr(c) for c in [76, 111])
QLAIID = "".join(chr(c) for c in [54, 48, 72, 90])
QLNMHX = 86
QNRSJM = 228
QNRXCH = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
QPLSPF = "".join(chr(c) for c in [83, 97, 110, 105, 79, 110, 84, 105, 109, 101])
QRJJJV = "".join(chr(c) for c in [75, 101, 101, 112, 79, 102, 102])
QSNQLN = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 55])
QXPICX = "".join(chr(c) for c in [83, 65, 78, 73])
RAHEOC = "".join(chr(c) for c in [])
RJHIUS = 208
RJZTAT = "".join(chr(c) for c in [79, 110, 80, 50])
RKINEJ = "".join(
    chr(c) for c in [82, 101, 112, 108, 97, 99, 101, 70, 105, 108, 116, 101, 114]
)
RSJMCB = 123
RTFMNH = "".join(chr(c) for c in [80, 97, 117, 115, 101])
RXCHWD = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        66,
        101,
        108,
        111,
        119,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
    ]
)
SAKQXP = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
SBDJQR = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        101,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
        79,
        110,
        72,
        101,
        97,
        116,
        101,
        114,
    ]
)
SELHBQ = "".join(
    chr(c)
    for c in [
        79,
        118,
        101,
        114,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
        69,
        110,
        97,
        98,
        108,
        101,
    ]
)
SIFJBI = 45
SIRYXB = "".join(chr(c) for c in [78, 111, 116, 65, 99, 116, 105, 118, 101])
SJMCBF = "".join(chr(c) for c in [79, 117, 116, 76, 105])
SJWMNZ = 64
SKSOKP = 223
SKWIVD = "".join(chr(c) for c in [80, 117, 109, 112, 49, 65, 115, 86, 83, 80])
SNQLNM = 85
SOKPHU = 224
SOOQNR = "".join(
    chr(c) for c in [79, 117, 116, 54, 65, 67, 117, 114, 114, 101, 110, 116]
)
SPBWJY = "".join(chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 66, 121])
SPFTSI = 42
SSAKQX = "".join(chr(c) for c in [70, 98, 76, 105])
SSUHBV = "".join(
    chr(c) for c in [67, 69, 95, 50, 120, 50, 48, 65, 108, 108, 111, 119, 101, 100]
)
SUHBVW = "".join(chr(c) for c in [70, 117, 115, 101, 77, 97, 112, 112, 105, 110, 103])
SXUJUT = 20
TACCPQ = "".join(
    chr(c) for c in [70, 105, 108, 116, 67, 80, 79, 84, 79, 112, 116, 105, 111, 110]
)
TATDZX = "".join(chr(c) for c in [68, 74, 83, 95, 78, 111, 50])
TBJEUT = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        65,
        115,
        67,
        111,
        111,
        108,
        105,
        110,
        103,
        68,
        101,
        118,
        105,
        99,
        101,
    ]
)
THBSKS = "".join(
    chr(c) for c in [79, 117, 116, 50, 65, 67, 117, 114, 114, 101, 110, 116]
)
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = 98
TIDUBS = 102
TOPHUG = 34
TSIFJB = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
TTIDUB = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 51])
TYIYWS = 37
UBSSUH = "".join(chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 116, 53])
UBYGDS = 8
UGTYIY = 36
UHBVWV = "".join(chr(c) for c in [85, 76])
UIKFWR = "".join(chr(c) for c in [67, 108, 101, 97, 110, 70, 105, 108, 116, 101, 114])
UJUTYE = 21
UNBLKX = 61
UNRJZT = "".join(chr(c) for c in [68, 74, 83, 95, 78, 111, 49])
UNXNKM = 27
UOJRJH = "".join(chr(c) for c in [79, 117, 116, 54, 65])
UQEXLS = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
USOOQN = 226
USPBWJ = "".join(chr(c) for c in [79, 51, 84, 111, 103, 103, 108, 105, 110, 103])
UTOPHU = "".join(
    chr(c)
    for c in [70, 97, 110, 83, 101, 116, 65, 79, 84, 84, 101, 109, 112, 65, 100, 99]
)
UTYEKC = "".join(chr(c) for c in [79, 119, 110])
UXFEFJ = 1
VDNQGV = 24
VDQLAI = "".join(
    chr(c) for c in [76, 105, 110, 101, 70, 114, 101, 113, 117, 101, 110, 99, 121]
)
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = 90
VLASSA = "".join(chr(c) for c in [76, 73])
VUNXNK = "".join(
    chr(c) for c in [86, 83, 80, 83, 112, 101, 101, 100, 76, 101, 118, 101, 108, 49]
)
VWVUBY = "".join(
    chr(c)
    for c in [
        67,
        69,
        95,
        74,
        109,
        112,
        50,
        95,
        51,
        95,
        73,
        110,
        115,
        116,
        97,
        108,
        108,
        101,
        100,
    ]
)
VYFCRT = "".join(
    chr(c)
    for c in [
        69,
        120,
        105,
        116,
        81,
        117,
        105,
        101,
        116,
        65,
        110,
        100,
        67,
        97,
        110,
        99,
        101,
        108,
        79,
        116,
        104,
        101,
        114,
        85,
        68,
    ]
)
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAJVDQ = 93
WAONPY = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
WBSIRY = "".join(
    chr(c) for c in [69, 99, 111, 110, 80, 114, 111, 103, 83, 116, 97, 116, 117, 115]
)
WDAFIK = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 84, 69, 110, 97, 98, 108, 101]
)
WIVDNQ = "".join(chr(c) for c in [80, 117, 109, 112, 51, 65, 115, 86, 83, 80])
WJYKLG = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
WMNZMJ = 65
WRKINE = "".join(chr(c) for c in [67, 108, 101, 97, 110, 67, 111, 118, 101, 114])
WSKWIV = 39
WVUBYG = "".join(
    chr(c)
    for c in [
        67,
        69,
        95,
        74,
        109,
        112,
        50,
        95,
        52,
        95,
        73,
        110,
        115,
        116,
        97,
        108,
        108,
        101,
        100,
    ]
)
XBQFYL = 17
XCHWDA = 74
XEKVKZ = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 51, 78, 98, 87, 101, 101, 107]
)
XFEFJT = "".join(chr(c) for c in [67, 108, 101, 97, 110, 67, 80])
XLSXUJ = 19
XNKMLO = 28
XPICXQ = "".join(chr(c) for c in [79, 78, 90, 69, 78])
XQGLRA = "".join(chr(c) for c in [79, 117, 116, 51, 65])
XQIEFX = 201
XSJWMN = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 67, 80, 77, 105, 110, 79, 110, 84, 105, 109, 101]
)
XTIACQ = "".join(
    chr(c) for c in [66, 114, 78, 98, 83, 101, 116, 116, 105, 110, 103, 115]
)
XUJUTY = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
XWAJVD = "".join(
    chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 55, 78, 98, 87, 101, 101, 107]
)
XYBQSN = 83
YBQSNQ = "".join(chr(c) for c in [75, 54, 48, 48, 77, 115, 103, 54])
YEKCWA = 6
YGDSBD = "".join(chr(c) for c in [65, 118, 97, 105, 108, 97, 98, 108, 101])
YIYWSK = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        67,
        108,
        114,
        70,
        111,
        114,
        99,
        101,
        79,
        102,
        102,
        84,
        101,
        109,
        112,
        65,
        100,
        99,
    ]
)
YKLGQP = "".join(
    chr(c) for c in [79, 51, 84, 111, 103, 103, 108, 101, 80, 101, 114, 105, 111, 100]
)
YLJUIK = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        99,
        107,
        79,
        110,
        79,
        102,
        102,
        75,
        101,
        121,
        69,
        110,
        97,
        98,
        108,
        101,
    ]
)
YNQJYM = 7
YOUSPB = "".join(
    chr(c) for c in [79, 51, 70, 111, 108, 108, 111, 119, 80, 117, 109, 112]
)
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YWSKWI = "".join(
    chr(c)
    for c in [
        70,
        97,
        110,
        70,
        111,
        114,
        99,
        101,
        79,
        102,
        102,
        73,
        110,
        104,
        105,
        98,
        105,
        116,
        68,
        101,
        108,
        97,
        121,
    ]
)
YXBQFY = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
YYLIUX = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZILXWA = 91
ZMJIGY = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
ZUQEXL = 96
AHEOCT = [
    JVHFTH,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    IVLASS,
]
AIIDNI = [QLAIID, LAIIDN]
ATDZXN = [
    BMJVHF,
    CXQIEF,
    QIEFXQ,
    EFXQGL,
    XQGLRA,
    GLRAHE,
    OKPHUO,
    PHUOJR,
    UOJRJH,
    JRJHIU,
    SJMCBF,
    CBFEGZ,
    FEGZUQ,
]
BQNRXC = [LHBQNR, HBQNRX]
DSBDJQ = [YGDSBD, GDSBDJ]
DZXNQT = []
FYLJUI = [BQFYLJ, QFYLJU]
GYOUSP = [JIGYOU, IGYOUS, PIPIVL, RAHEOC]
HTBJEU = [NHTBJE, IGYOUS, PIPIVL]
ICXQIE = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    LASSAK,
    ASSAKQ,
    SSAKQX,
    SAKQXP,
    AKQXPI,
    KQXPIC,
    QXPICX,
    XPICXQ,
    PICXQI,
]
IKJPUN = [AFIKJP, FIKJPU]
KINEJN = [UIKFWR, IKFWRK, KFWRKI, FWRKIN, WRKINE, RKINEJ]
LOIJUG = [RAHEOC, PIPIVL, IGYOUS]
MCBFEG = [
    JVHFTH,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    RAHEOC,
    VLASSA,
]
NIBXTI = [IDNIBX, DNIBXT]
QIPOUY = [CPQIPO, PQIPOU]
RJJJVY = [DJQRJJ, JQRJJJ, QRJJJV, RAHEOC]
RYXBQF = [BSIRYX, SIRYXB, JVHFTH, IRYXBQ]
TDZXNQ = [VLASSA]
TFMNHT = [CRTFMN, RTFMNH]
TYEKCW = [JUTYEK, UTYEKC]
UGSELH = [IJUGSE, JUGSEL]
UYNQJY = [POUYNQ, OUYNQJ]
VUBYGD = [UHBVWV, HBVWVU, BVWVUB, VWVUBY, WVUBYG, RAHEOC, RAHEOC, RAHEOC]
YFCRTF = [JJVYFC, JVYFCR, JVHFTH, VYFCRT]
YLIUXF = [ONPYYL, NPYYLI, PYYLIU, YYLIUX]
YMOUNB = [QJYMOU, JYMOUN]
ZTATDZ = [JVHFTH, NRJZTA, RJZTAT, JZTATD]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return JTACCP

    @property
    def output_keys(self):
        return ATDZXN

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, ICXQIE, None, None, QBMJVH
            ),
            CXQIEF: GeckoEnumStructAccessor(
                self.struct, CXQIEF, XQIEFX, None, ICXQIE, None, None, QBMJVH
            ),
            QIEFXQ: GeckoEnumStructAccessor(
                self.struct, QIEFXQ, IEFXQG, None, ICXQIE, None, None, QBMJVH
            ),
            EFXQGL: GeckoEnumStructAccessor(
                self.struct, EFXQGL, FXQGLR, None, ICXQIE, None, None, QBMJVH
            ),
            XQGLRA: GeckoEnumStructAccessor(
                self.struct, XQGLRA, QGLRAH, None, ICXQIE, None, None, QBMJVH
            ),
            GLRAHE: GeckoEnumStructAccessor(
                self.struct, GLRAHE, LRAHEO, None, AHEOCT, None, None, QBMJVH
            ),
            HEOCTH: GeckoByteStructAccessor(self.struct, HEOCTH, EOCTHB, QBMJVH),
            OCTHBS: GeckoByteStructAccessor(self.struct, OCTHBS, CTHBSK, QBMJVH),
            THBSKS: GeckoByteStructAccessor(self.struct, THBSKS, HBSKSO, QBMJVH),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, QBMJVH),
            KSOKPH: GeckoByteStructAccessor(self.struct, KSOKPH, SOKPHU, QBMJVH),
            OKPHUO: GeckoEnumStructAccessor(
                self.struct, OKPHUO, KPHUOJ, None, ICXQIE, None, None, QBMJVH
            ),
            PHUOJR: GeckoEnumStructAccessor(
                self.struct, PHUOJR, HUOJRJ, None, ICXQIE, None, None, QBMJVH
            ),
            UOJRJH: GeckoEnumStructAccessor(
                self.struct, UOJRJH, OJRJHI, None, ICXQIE, None, None, QBMJVH
            ),
            JRJHIU: GeckoEnumStructAccessor(
                self.struct, JRJHIU, RJHIUS, None, ICXQIE, None, None, QBMJVH
            ),
            JHIUSO: GeckoByteStructAccessor(self.struct, JHIUSO, HIUSOO, QBMJVH),
            IUSOOQ: GeckoByteStructAccessor(self.struct, IUSOOQ, USOOQN, QBMJVH),
            SOOQNR: GeckoByteStructAccessor(self.struct, SOOQNR, OOQNRS, QBMJVH),
            OQNRSJ: GeckoByteStructAccessor(self.struct, OQNRSJ, QNRSJM, QBMJVH),
            NRSJMC: GeckoByteStructAccessor(self.struct, NRSJMC, RSJMCB, QBMJVH),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, JMCBFE, None, MCBFEG, None, None, QBMJVH
            ),
            CBFEGZ: GeckoEnumStructAccessor(
                self.struct, CBFEGZ, BFEGZU, None, ICXQIE, None, None, QBMJVH
            ),
            FEGZUQ: GeckoEnumStructAccessor(
                self.struct, FEGZUQ, EGZUQE, None, ICXQIE, None, None, QBMJVH
            ),
            GZUQEX: GeckoByteStructAccessor(self.struct, GZUQEX, ZUQEXL, QBMJVH),
            UQEXLS: GeckoByteStructAccessor(self.struct, UQEXLS, QEXLSX, QBMJVH),
            EXLSXU: GeckoByteStructAccessor(self.struct, EXLSXU, XLSXUJ, QBMJVH),
            LSXUJU: GeckoByteStructAccessor(self.struct, LSXUJU, SXUJUT, QBMJVH),
            XUJUTY: GeckoEnumStructAccessor(
                self.struct, XUJUTY, UJUTYE, YEKCWA, TYEKCW, None, EKCWAO, QBMJVH
            ),
            KCWAON: GeckoByteStructAccessor(self.struct, KCWAON, CWAONP, QBMJVH),
            WAONPY: GeckoEnumStructAccessor(
                self.struct, WAONPY, AONPYY, None, YLIUXF, None, None, QBMJVH
            ),
            LIUXFE: GeckoBoolStructAccessor(
                self.struct, LIUXFE, IUXFEF, UXFEFJ, QBMJVH
            ),
            XFEFJT: GeckoBoolStructAccessor(
                self.struct, XFEFJT, IUXFEF, EKCWAO, QBMJVH
            ),
            FEFJTA: GeckoBoolStructAccessor(
                self.struct, FEFJTA, IUXFEF, EFJTAC, QBMJVH
            ),
            FJTACC: GeckoBoolStructAccessor(
                self.struct, FJTACC, IUXFEF, JTACCP, QBMJVH
            ),
            TACCPQ: GeckoBoolStructAccessor(
                self.struct, TACCPQ, IUXFEF, ACCPQI, QBMJVH
            ),
            CCPQIP: GeckoEnumStructAccessor(
                self.struct, CCPQIP, IUXFEF, YEKCWA, QIPOUY, None, EKCWAO, QBMJVH
            ),
            IPOUYN: GeckoEnumStructAccessor(
                self.struct, IPOUYN, IUXFEF, YNQJYM, UYNQJY, None, EKCWAO, QBMJVH
            ),
            NQJYMO: GeckoEnumStructAccessor(
                self.struct, NQJYMO, IUXFEF, MOUNBL, YMOUNB, None, EKCWAO, QBMJVH
            ),
            OUNBLK: GeckoByteStructAccessor(self.struct, OUNBLK, UNBLKX, QBMJVH),
            NBLKXS: GeckoByteStructAccessor(self.struct, NBLKXS, BLKXSJ, QBMJVH),
            LKXSJW: GeckoByteStructAccessor(self.struct, LKXSJW, KXSJWM, QBMJVH),
            XSJWMN: GeckoByteStructAccessor(self.struct, XSJWMN, SJWMNZ, QBMJVH),
            JWMNZM: GeckoByteStructAccessor(self.struct, JWMNZM, WMNZMJ, QBMJVH),
            MNZMJI: GeckoByteStructAccessor(self.struct, MNZMJI, NZMJIG, QBMJVH),
            ZMJIGY: GeckoEnumStructAccessor(
                self.struct, ZMJIGY, MJIGYO, MOUNBL, GYOUSP, None, EFJTAC, QBMJVH
            ),
            YOUSPB: GeckoBoolStructAccessor(
                self.struct, YOUSPB, MJIGYO, EKCWAO, QBMJVH
            ),
            OUSPBW: GeckoBoolStructAccessor(
                self.struct, OUSPBW, MJIGYO, JTACCP, QBMJVH
            ),
            USPBWJ: GeckoBoolStructAccessor(
                self.struct, USPBWJ, MJIGYO, EFJTAC, QBMJVH
            ),
            SPBWJY: GeckoEnumStructAccessor(
                self.struct, SPBWJY, MJIGYO, YEKCWA, QIPOUY, None, None, QBMJVH
            ),
            PBWJYK: GeckoByteStructAccessor(self.struct, PBWJYK, BWJYKL, QBMJVH),
            WJYKLG: GeckoByteStructAccessor(self.struct, WJYKLG, JYKLGQ, QBMJVH),
            YKLGQP: GeckoByteStructAccessor(self.struct, YKLGQP, KLGQPL, QBMJVH),
            LGQPLS: GeckoByteStructAccessor(self.struct, LGQPLS, GQPLSP, QBMJVH),
            QPLSPF: GeckoByteStructAccessor(self.struct, QPLSPF, PLSPFT, QBMJVH),
            LSPFTS: GeckoByteStructAccessor(self.struct, LSPFTS, SPFTSI, QBMJVH),
            PFTSIF: GeckoTimeStructAccessor(self.struct, PFTSIF, FTSIFJ, QBMJVH),
            TSIFJB: GeckoTimeStructAccessor(self.struct, TSIFJB, SIFJBI, QBMJVH),
            IFJBIA: GeckoTimeStructAccessor(self.struct, IFJBIA, FJBIAM, QBMJVH),
            JBIAMJ: GeckoTimeStructAccessor(self.struct, JBIAMJ, BIAMJM, QBMJVH),
            IAMJMA: GeckoByteStructAccessor(self.struct, IAMJMA, AMJMAO, QBMJVH),
            MJMAOA: GeckoTimeStructAccessor(self.struct, MJMAOA, JMAOAW, QBMJVH),
            MAOAWB: GeckoTimeStructAccessor(self.struct, MAOAWB, AOAWBS, QBMJVH),
            OAWBSI: GeckoBoolStructAccessor(
                self.struct, OAWBSI, AWBSIR, JTACCP, QBMJVH
            ),
            WBSIRY: GeckoEnumStructAccessor(
                self.struct, WBSIRY, AWBSIR, EFJTAC, RYXBQF, None, EFJTAC, QBMJVH
            ),
            YXBQFY: GeckoEnumStructAccessor(
                self.struct, YXBQFY, XBQFYL, MOUNBL, FYLJUI, None, EKCWAO, QBMJVH
            ),
            YLJUIK: GeckoBoolStructAccessor(
                self.struct, YLJUIK, XBQFYL, UXFEFJ, QBMJVH
            ),
            VDQLAI: GeckoEnumStructAccessor(
                self.struct, VDQLAI, DQLAII, EFJTAC, AIIDNI, None, EKCWAO, QBMJVH
            ),
            IIDNIB: GeckoEnumStructAccessor(
                self.struct, IIDNIB, DQLAII, ACCPQI, NIBXTI, None, EKCWAO, QBMJVH
            ),
            IBXTIA: GeckoByteStructAccessor(self.struct, IBXTIA, BXTIAC, None),
            XTIACQ: GeckoByteStructAccessor(self.struct, XTIACQ, TIACQF, None),
            IACQFF: GeckoByteStructAccessor(self.struct, IACQFF, ACQFFT, None),
            CQFFTT: GeckoByteStructAccessor(self.struct, CQFFTT, QFFTTI, QBMJVH),
            FFTTID: GeckoByteStructAccessor(self.struct, FFTTID, FTTIDU, QBMJVH),
            TTIDUB: GeckoByteStructAccessor(self.struct, TTIDUB, TIDUBS, QBMJVH),
            IDUBSS: GeckoByteStructAccessor(self.struct, IDUBSS, DUBSSU, QBMJVH),
            UBSSUH: GeckoByteStructAccessor(self.struct, UBSSUH, BSSUHB, QBMJVH),
            SSUHBV: GeckoBoolStructAccessor(
                self.struct, SSUHBV, AWBSIR, YEKCWA, QBMJVH
            ),
            SUHBVW: GeckoEnumStructAccessor(
                self.struct, SUHBVW, DQLAII, UXFEFJ, VUBYGD, None, UBYGDS, QBMJVH
            ),
            BYGDSB: GeckoEnumStructAccessor(
                self.struct, BYGDSB, DQLAII, YNQJYM, DSBDJQ, None, EKCWAO, QBMJVH
            ),
            SBDJQR: GeckoEnumStructAccessor(
                self.struct, SBDJQR, BDJQRJ, JTACCP, RJJJVY, None, EFJTAC, QBMJVH
            ),
            JJJVYF: GeckoEnumStructAccessor(
                self.struct, JJJVYF, AWBSIR, UXFEFJ, YFCRTF, None, EFJTAC, QBMJVH
            ),
            FCRTFM: GeckoEnumStructAccessor(
                self.struct, FCRTFM, AWBSIR, MOUNBL, TFMNHT, None, EKCWAO, QBMJVH
            ),
            FMNHTB: GeckoEnumStructAccessor(
                self.struct, FMNHTB, MNHTBJ, UXFEFJ, HTBJEU, None, EFJTAC, QBMJVH
            ),
            TBJEUT: GeckoBoolStructAccessor(
                self.struct, TBJEUT, MNHTBJ, JTACCP, QBMJVH
            ),
            BJEUTO: GeckoBoolStructAccessor(
                self.struct, BJEUTO, BDJQRJ, ACCPQI, QBMJVH
            ),
            JEUTOP: GeckoBoolStructAccessor(
                self.struct, JEUTOP, BDJQRJ, YEKCWA, QBMJVH
            ),
            EUTOPH: GeckoBoolStructAccessor(
                self.struct, EUTOPH, BDJQRJ, YNQJYM, QBMJVH
            ),
            UTOPHU: GeckoByteStructAccessor(self.struct, UTOPHU, TOPHUG, QBMJVH),
            OPHUGT: GeckoByteStructAccessor(self.struct, OPHUGT, PHUGTY, QBMJVH),
            HUGTYI: GeckoByteStructAccessor(self.struct, HUGTYI, UGTYIY, QBMJVH),
            GTYIYW: GeckoByteStructAccessor(self.struct, GTYIYW, TYIYWS, QBMJVH),
            YIYWSK: GeckoByteStructAccessor(self.struct, YIYWSK, IYWSKW, QBMJVH),
            YWSKWI: GeckoByteStructAccessor(self.struct, YWSKWI, WSKWIV, QBMJVH),
            SKWIVD: GeckoBoolStructAccessor(
                self.struct, SKWIVD, KWIVDN, MOUNBL, QBMJVH
            ),
            WIVDNQ: GeckoBoolStructAccessor(
                self.struct, WIVDNQ, KWIVDN, EKCWAO, QBMJVH
            ),
            IVDNQG: GeckoByteStructAccessor(self.struct, IVDNQG, VDNQGV, QBMJVH),
            DNQGVU: GeckoByteStructAccessor(self.struct, DNQGVU, NQGVUN, QBMJVH),
            QGVUNX: GeckoByteStructAccessor(self.struct, QGVUNX, GVUNXN, QBMJVH),
            VUNXNK: GeckoByteStructAccessor(self.struct, VUNXNK, UNXNKM, QBMJVH),
            NXNKML: GeckoByteStructAccessor(self.struct, NXNKML, XNKMLO, QBMJVH),
            NKMLOI: GeckoByteStructAccessor(self.struct, NKMLOI, KMLOIJ, QBMJVH),
            MLOIJU: GeckoEnumStructAccessor(
                self.struct, MLOIJU, BDJQRJ, None, LOIJUG, None, EFJTAC, QBMJVH
            ),
            OIJUGS: GeckoEnumStructAccessor(
                self.struct, OIJUGS, DQLAII, YEKCWA, UGSELH, None, EKCWAO, QBMJVH
            ),
            GSELHB: GeckoBoolStructAccessor(
                self.struct, GSELHB, MNHTBJ, EFJTAC, QBMJVH
            ),
            SELHBQ: GeckoBoolStructAccessor(
                self.struct, SELHBQ, MNHTBJ, ACCPQI, QBMJVH
            ),
            ELHBQN: GeckoEnumStructAccessor(
                self.struct, ELHBQN, BDJQRJ, EKCWAO, BQNRXC, None, EKCWAO, QBMJVH
            ),
            QNRXCH: GeckoTempStructAccessor(self.struct, QNRXCH, NRXCHW, QBMJVH),
            RXCHWD: GeckoByteStructAccessor(self.struct, RXCHWD, XCHWDA, QBMJVH),
            CHWDAF: GeckoByteStructAccessor(self.struct, CHWDAF, HWDAFI, QBMJVH),
            WDAFIK: GeckoBoolStructAccessor(
                self.struct, WDAFIK, MNHTBJ, MOUNBL, QBMJVH
            ),
            DAFIKJ: GeckoEnumStructAccessor(
                self.struct, DAFIKJ, DQLAII, MOUNBL, IKJPUN, None, EKCWAO, QBMJVH
            ),
            KJPUNR: GeckoBoolStructAccessor(
                self.struct, KJPUNR, UJUTYE, MOUNBL, QBMJVH
            ),
            JPUNRJ: GeckoBoolStructAccessor(
                self.struct, JPUNRJ, UJUTYE, UXFEFJ, QBMJVH
            ),
            PUNRJZ: GeckoBoolStructAccessor(
                self.struct, PUNRJZ, UJUTYE, YEKCWA, QBMJVH
            ),
            UNRJZT: GeckoEnumStructAccessor(
                self.struct, UNRJZT, UJUTYE, EKCWAO, ZTATDZ, None, EFJTAC, QBMJVH
            ),
            TATDZX: GeckoEnumStructAccessor(
                self.struct, TATDZX, UJUTYE, EFJTAC, ZTATDZ, None, EFJTAC, QBMJVH
            ),
        }
